::: {#navbar .navbar .navbar-default .navbar-fixed-top role="navigation"}
::: {.container}
::: {.navbar-header}
[]{.icon-bar} []{.icon-bar} []{.icon-bar}

<div>

[![](../_static/img/RAIcon.png)](/runestone/default/user/login){.brand-logo}
[fopp](../index.html){#rs-book-toc-link .navbar-brand}

</div>
:::

::: {.navbar-collapse .collapse .navbar-ex1-collapse}
-   
-   []{#ad_warning}
-   []{#browsing_warning}
-   
-   [*[Search]{.visuallyhidden
    aria-label="Search"}*](#){.dropdown-toggle}
    -   [Table of Contents](../index.html)

    -   [Book Index](../genindex.html)

    -   

    -   ::: {.input-group}
        :::
-   
-   [*[User]{.visuallyhidden aria-label="User"}*](#){.dropdown-toggle}
    -   []{.loggedinuser}

    -   

    -   [Course Home](/ns/course/index)

    -   [Assignments](/assignment/student/chooseAssignment)

    -   [Practice](/runestone/assignments/practice)

    -   [[Peer Instruction
        (Instructor)](/runestone/peer/instructor.html)]{#inst_peer_link}

    -   [Peer Instruction (Student)](/runestone/peer/student.html)

    -   

    -   [Change Course](/runestone/default/courses)

    -   

    -   [[Instructor\'s
        Page](/runestone/admin/index)]{#ip_dropdown_link}

    -   [Progress Page](/runestone/dashboard/studentreport)

    -   

    -   [Edit Profile](/runestone/default/user/profile){#profilelink}

    -   [Change
        Password](/runestone/default/user/change_password){#passwordlink}

    -   [Register](/runestone/default/user/register){#registerlink}

    -   [Login](#)

    -   ::: {.slider .round}
        :::

        Dark Mode
-   
-   [[*[Scratch Activecode]{.visuallyhidden
    aria-label="Scratch Activecode"}*](javascript:runestoneComponents.popupScratchAC())]{#scratch_ac_link}
-   
-   [*[Help]{.visuallyhidden aria-label="Help"}*](#){.dropdown-toggle}
    -   [FAQ](http://runestoneinteractive.org/pages/faq.html)
    -   [Instructors Guide](https://guide.runestone.academy)
    -   
    -   [About Runestone](http://runestoneinteractive.org)
    -   [Report A
        Problem](/runestone/default/reportabug?course=fopp&page=chapterProject)
-   

```{=html}
<!-- -->
```
-   
-   [This Chapter](../index.html){.dropdown-toggle}
    -   [22.1 Introduction: Class Inheritance](intro.html){.reference
        .internal}
    -   [22.2 Inheriting Variables and
        Methods](inheritVarsAndMethods.html){.reference .internal}
    -   [22.3 Overriding Methods](OverrideMethods.html){.reference
        .internal}
    -   [22.4 Invoking the Parent Class's
        Method](InvokingSuperMethods.html){.reference .internal}
    -   [22.5 Multiple inheritance](MultipleInheritance.html){.reference
        .internal}
    -   [22.6 Tamagotchi Revisited](TamagotchiRevisited.html){.reference
        .internal}
    -   [22.7 Exercises](Exercises.html){.reference .internal}
    -   [22.8 Chapter Assessment](ChapterAssessment.html){.reference
        .internal}
    -   [22.9 Project - Wheel of Python](chapterProject.html){.reference
        .internal}
-   
-   
:::
:::
:::

::: {#continue-reading .container}
:::

::: {#main-content .container role="main"}
::: {#project-wheel-of-python .section}
[22.9. ]{.section-number}Project - Wheel of Python[¶](#project-wheel-of-python "Permalink to this heading"){.headerlink}
========================================================================================================================

::: {.runestone .explainer .ac_section}
::: {#wof_ac_sleep component="activecode" question_label="22.9.1"}
::: {#wof_ac_sleep_question .ac_question}
This project will take you through the process of implementing a
simplified version of the game **Wheel of Fortune**. Here are the rules
of our game:

-   

    There are `num_human`{.docutils .literal .notranslate} human players and `num_computer`{.docutils .literal .notranslate} computer players.

    :   -   Every player has *some* amount of money (\$0 at the start of
            the game)

        -   Every player has a set of prizes (none at the start of the
            game)

-   

    The goal is to **guess a phrase within a given category**. For example:

    :   -   Category: **Artist & Song**

        -   Phrase: **Whitney Houston's I Will Always Love You**

-   

    Players see the category and an obscured version of the phrase where every alphanumeric character in the phrase starts out as hidden (using underscores: `_`{.docutils .literal .notranslate}):

    :   -   Category: **Artist & Song**

        -   Phrase: `_______ _______'_ _ ____ ______ ____ ___`{.docutils
            .literal .notranslate}

-   Note that case (capitalization) does not matter

-   

    During their turn, every player spins the wheel to determine a prize amount and:

    :   -   

            If the wheel lands on a **cash** square, players may do one of three actions:

            :   -   

                    **Guess any letter** that hasn't been guessed by typing a letter (a-z)

                    :   -   Vowels (a, e, i, o, u) cost \$250 to guess
                            and can't be guessed if the player doesn't
                            have enough money. All other letters are
                            "free" to guess

                        -   The player can guess any letter that hasn't
                            been guessed and gets that cash amount for
                            *every time* that letter appears in the
                            phrase

                        -   If there is a prize, the user also gets that
                            prize (in addition to any prizes they
                            already had)

                        -   

                            Example: The user lands on \$500 and guesses 'W'

                            :   -   There are three W's in the phrase,
                                    so the player wins \$1500

                -   

                    **Guess the complete phrase** by typing a phrase (anything over one character that isn't 'pass')

                    :   -   If they are correct, they win the game

                        -   If they are incorrect, it is the next
                            player's turn

                -   **Pass** their turn by entering `'pass'`{.docutils
                    .literal .notranslate}

        -   If the wheel lands on **"lose a turn"**, the player loses
            their turn and the game moves on to the next player

        -   If the wheel lands on **"bankrupt"**, the player loses their
            turn *and* loses their money. However, they keep all of the
            prizes they have won so far.

-   The game continues until the entire phrase is revealed (or one
    player guesses the complete phrase)

First, let's learn about a few functions and methods that we'll use
along the way to do this project. There are no questions to answer in
these next few active code windows, they are just here to introduce or
reintroduce you to some functions and methods that you may not be aware
of. The active code window that starts with "Part A" is where you are
first asked to complete code.

The `time.sleep(s)`{.docutils .literal .notranslate} function (from the
`time`{.docutils .literal .notranslate} module) delays execution of the
next line of code for `s`{.docutils .literal .notranslate} seconds.
You'll find that we can build a little suspense during gameplay with
some well-placed delays. The game can also be easier for users to
understand if not everything happens instantly.
:::
:::
:::

::: {.runestone .explainer .ac_section}
::: {#wof_ac_rand component="activecode" question_label="22.9.2"}
::: {#wof_ac_rand_question .ac_question}
The `random`{.docutils .literal .notranslate} module includes several
useful methods for generating and using random numbers, including:

-   `random.randint(low, high)`{.docutils .literal .notranslate}
    generates a random number between `low`{.docutils .literal
    .notranslate} and `high`{.docutils .literal .notranslate}
    (inclusive)

-   `random.choice(L)`{.docutils .literal .notranslate} selects a random
    item from the list `L`{.docutils .literal .notranslate}
:::
:::
:::

::: {.runestone .explainer .ac_section}
::: {#wof_ac_str component="activecode" question_label="22.9.3"}
::: {#wof_ac_str_question .ac_question}
There are also several string methods that we haven't gone over in
detail but will use for this project:

-   `.upper()`{.docutils .literal .notranslate} converts a string to
    uppercase (the opposite is `.lower()`{.docutils .literal
    .notranslate})

-   `.count(s)`{.docutils .literal .notranslate} counts how many times
    the string `s`{.docutils .literal .notranslate} occurs inside of a
    larger string
:::
:::
:::

::: {.runestone .explainer .ac_section}
::: {#wof_ac_other_methods component="activecode" question_label="22.9.4"}
::: {#wof_ac_other_methods_question .ac_question}
We're going to define a few useful methods for you. Read their
implementation and make sure they make sense.
:::
:::
:::

::: {.runestone .explainer .ac_section}
::: {#wof_ac_wof_player component="activecode" question_label="22.9.5"}
::: {#wof_ac_wof_player_question .ac_question}
**Part A: \`\`WOFPlayer\`\`**

We're going to start by defining a class to represent a Wheel of Fortune
player, called `WOFPlayer`{.docutils .literal .notranslate}. Every
instance of `WOFPlayer`{.docutils .literal .notranslate} has three
instance variables:

-   `.name`{.docutils .literal .notranslate}: The name of the player
    (should be passed into the constructor)

-   `.prizeMoney`{.docutils .literal .notranslate}: The amount of prize
    money for this player (an integer, initialized to `0`{.docutils
    .literal .notranslate})

-   `.prizes`{.docutils .literal .notranslate}: The prizes this player
    has won so far (a list, initialized to `[]`{.docutils .literal
    .notranslate})

It should also have the following methods (note: we will exclude
`self`{.docutils .literal .notranslate} in our descriptions):

-   `.addMoney(amt)`{.docutils .literal .notranslate}: Add
    `amt`{.docutils .literal .notranslate} to
    `self.prizeMoney`{.docutils .literal .notranslate}

-   `.goBankrupt()`{.docutils .literal .notranslate}: Set
    `self.prizeMoney`{.docutils .literal .notranslate} to `0`{.docutils
    .literal .notranslate}

-   `.addPrize(prize)`{.docutils .literal .notranslate}: Add
    `prize`{.docutils .literal .notranslate} to `self.prizes`{.docutils
    .literal .notranslate}

-   

    `.__str__()`{.docutils .literal .notranslate}: Returns the player's name and prize money in the following format:

    :   -   `Steve ($1800)`{.docutils .literal .notranslate} (for a
            player with instance variables `.name == 'Steve'`{.docutils
            .literal .notranslate} and `prizeMoney == 1800`{.docutils
            .literal .notranslate})

**Part B: \`\`WOFHumanPlayer\`\`** Next, we're going to define a class
named `WOFHumanPlayer`{.docutils .literal .notranslate}, which should
inherit from `WOFPlayer`{.docutils .literal .notranslate} (part A). This
class is going to represent a human player. In addition to having all of
the instance variables and methods that `WOFPlayer`{.docutils .literal
.notranslate} has, `WOFHumanPlayer`{.docutils .literal .notranslate}
should have an additional method:

-   `.getMove(category, obscuredPhrase, guessed)`{.docutils .literal
    .notranslate}: Should ask the user to enter a move and return
    **whatever they entered** no matter what they enter.

`.getMove()`{.docutils .literal .notranslate}'s prompt should be:

::: {.highlight-default .notranslate}
::: {.highlight}
    {name} has ${prizeMoney}

    Category: {category}
    Phrase:  {obscured_phrase}
    Guessed: {guessed}

    Guess a letter, phrase, or type 'exit' or 'pass':
:::
:::

For example:

::: {.highlight-default .notranslate}
::: {.highlight}
    Steve has $200

    Category: Places
    Phrase: _L___ER N____N_L P_RK
    Guessed: B, E, K, L, N, P, R, X, Z

    Guess a letter, phrase, or type 'exit' or 'pass':
:::
:::

The user can then enter: \* `'exit'`{.docutils .literal .notranslate} to
exit the game \* `'pass'`{.docutils .literal .notranslate} to skip their
turn \* a single character to guess that character \* a complete phrase
-- anything other than `'exit'`{.docutils .literal .notranslate} or
`'pass'`{.docutils .literal .notranslate} -- to guess that phrase

Note that `.getMove()`{.docutils .literal .notranslate} **does not**
need to enforce anything about the user's input; that will be done via
the game logic.

**Part C: \`\`WOFComputerPlayer\`\`** Next, we're going to define a
class named `WOFComputerPlayer`{.docutils .literal .notranslate}, which
should inherit from `WOFPlayer`{.docutils .literal .notranslate} (part
A). This class is going to represent a computer player.

Every computer player will have a `difficulty`{.docutils .literal
.notranslate}, where players with a higher `difficulty`{.docutils
.literal .notranslate} generally play "better". There are many ways to
implement this. We'll do the following:

-   

    Semi-randomly decide whether to make a "good" move or a "bad" move on a given turn (a higher difficulty should make it more likely for the player to make a "good" move)

    :   -   If we decide to make a "bad" move, we'll randomly decide on
            a possible letter

        -   If we decide to make a "good" move, we'll choose a letter
            according to their overall frequency in the English language

-   If there aren't any possible letters to choose (for example: if the
    last character is a vowel but this player doesn't have enough to
    guess a vowel), we'll `'pass'`{.docutils .literal .notranslate}

We'll implement this in the `WOFComputerPlayer`{.docutils .literal
.notranslate} class. In addition to having all of the instance variables
and methods that `WOFPlayer`{.docutils .literal .notranslate} has,
`WOFComputerPlayer`{.docutils .literal .notranslate} should have:

**Class variable**

-   `.SORTED_FREQUENCIES`{.docutils .literal .notranslate}: Should be
    set to `'ZQXJKVBPYGFWMUCLDRHSNIOATE'`{.docutils .literal
    .notranslate}, which is a list of English characters sorted from
    least frequent (`'Z'`{.docutils .literal .notranslate}) to most
    frequent (`'E'`{.docutils .literal .notranslate}). We'll use this
    when trying to make a "good" move.

**Instance variables**

-   `.difficulty`{.docutils .literal .notranslate}: The level of
    difficulty for this computer (should be passed as the second
    argument into the constructor after `.name`{.docutils .literal
    .notranslate})

**Methods**

-   `.smartCoinFlip()`{.docutils .literal .notranslate}: This method
    will help us decide semi-randomly whether to make a "good" or "bad"
    move (again, a higher difficulty should make us more likely to make
    a "good" move). You should implement this by choosing a random
    number between `1`{.docutils .literal .notranslate} and
    `10`{.docutils .literal .notranslate} using
    `random.randint`{.docutils .literal .notranslate} (see above) and
    returning `True`{.docutils .literal .notranslate} if that random
    number is greater than `self.difficulty`{.docutils .literal
    .notranslate}. If the random number is equal to or less than
    `self.difficulty`{.docutils .literal .notranslate} then you should
    return `False`{.docutils .literal .notranslate}.

-   

    `.getPossibleLetters(guessed)`{.docutils .literal .notranslate}: This method should return a list of letters that can be guessed.

    :   -   These should be characters that are in `LETTERS`{.docutils
            .literal .notranslate}
            (`'ABCDEFGHIJKLMNOPQRSTUVWXYZ'`{.docutils .literal
            .notranslate}) but **not** in the `guessed`{.docutils
            .literal .notranslate} parameter.

        -   Additionally, if this player doesn't have enough prize money
            to guess a vowel (`VOWEL_COST`{.docutils .literal
            .notranslate}), then vowels (`VOWELS`{.docutils .literal
            .notranslate}: `'AEIOU'`{.docutils .literal .notranslate})
            should **not** be included

-   

    `.getMove(category, obscuredPhrase, guessed)`{.docutils .literal .notranslate}: Should return a valid move.

    :   -   Use the `.getPossibleLetters(guessed)`{.docutils .literal
            .notranslate} method described above.

        -   If there aren't any letters that can be guessed (this can
            happen if the only letters left to guess are vowels and the
            player doesn't have enough for vowels), return
            `'pass'`{.docutils .literal .notranslate}

        -   

            Use the `.smartCoinFlip()`{.docutils .literal .notranslate} method to decide whether to make a "good" or a "bad" move

            :   -   If making a "good" move
                    (`.smartCoinFlip()`{.docutils .literal .notranslate}
                    returns `True`{.docutils .literal .notranslate}),
                    then return the most frequent (highest index in
                    `.SORTED_FREQUENCIES`{.docutils .literal
                    .notranslate}) possible character

                -   If making a "bad" move (`.smartCoinFlip()`{.docutils
                    .literal .notranslate} returns `False`{.docutils
                    .literal .notranslate}), then return a random
                    character from the set of possible characters (use
                    `random.choice()`{.docutils .literal .notranslate})
:::
:::
:::

::: {.runestone .explainer .ac_section}
::: {#wof_ac_final component="activecode" question_label="22.9.6"}
::: {#wof_ac_final_question .ac_question}
**Putting it together: Wheel of Python**

Below is the game logic for the rest of the "Wheel of Python" game. We
have implemented most of the game logic. **Start by carefully reading
this code and double checking that it all makes sense**. Then, paste
your code from the previous code window in the correct places below.

*One more thing*: we added the following code to ensure that the Python
interpreter gives our game time to run
`sys.setExecutionLimit(ms)`{.docutils .literal .notranslate} says that
we should be able to run our program for `ms`{.docutils .literal
.notranslate} milliseconds before it gets stopped automatically:

::: {.highlight-default .notranslate}
::: {.highlight}
    import sys
    sys.setExecutionLimit(600000)
:::
:::
:::
:::
:::

::: {.runestone .datafile}
::: {.datafile_caption}
Data file: `wheel.json`
:::

``` {#wheel.json component="datafile" edit="false" data-rows="20" data-cols="39"}
[
    {
        "type": "cash",
        "text": "$950",
        "value": 950,
        "prize": "A trip to Ann Arbor!"
    },
    {
        "type": "bankrupt",
        "text": "Bankrupt",
        "prize": false
    },
    {
        "type": "loseturn",
        "text": "Lose a turn",
        "prize": false
    },
    {
        "type": "cash",
        "text": "$2500",
        "value": 2500,
        "prize": false
    },
    {
        "type": "cash",
        "text": "$900",
        "value": 900,
        "prize": false
    },
    {
        "type": "cash",
        "text": "$700",
        "value": 700,
        "prize": false
    },
    {
        "type": "cash",
        "text": "$600",
        "value": 600,
        "prize": false
    },
    {
        "type": "cash",
        "text": "$800",
        "value": 800,
        "prize": false
    },
    {
        "type": "cash",
        "text": "One Million",
        "value": 1000000,
        "prize": false
    },
    {
        "type": "cash",
        "text": "$650",
        "value": 650,
        "prize": "A brand new car!"
    },
    {
        "type": "cash",
        "text": "900",
        "value": 900,
        "prize": false
    },
    {
        "type": "cash",
        "text": "$700",
        "value": 700,
        "prize": false
    },
    {
        "type": "cash",
        "text": "$600",
        "value": 600,
        "prize": false
    }
]
```
:::

::: {.runestone .datafile}
::: {.datafile_caption}
Data file: `phrases.json`
:::

``` {#phrases.json component="datafile" edit="false" data-rows="20" data-cols="55"}
{
"Star & Role": [
    "Adam Sandler As Happy Gilmore",
    "Anthony Hopkins As Nixon",
    "Bob Denver As Gilligan",
    "Candice Bergen As Murphy Brown",
    "Don Johnson As Nash Bridges",
    "Eddie Murphy As The Nutty Professor",
    "Elizabeth Taylor & Richard Burton In Cleopatra",
    "Fran Drescher As The Nanny",
    "Jim Carrey As Ace Ventura",
    "Lea Thompson As Caroline In The City",
    "Marlo Thomas As That Girl",
    "Michael Douglas As The American President",
    "Paul Newman As Butch Cassidy",
    "Peter Falk As Columbo",
    "Peter O'Toole As Lawrence Of Arabia",
    "Pierce Brosnan As James Bond",
    "Sally Field As Norma Rae",
    "Sally Field As The Flying Nun",
    "Steve Martin In Father Of The Bride",
    "Telly Savalas As Kojak",
    "Tom Hanks As Forrest Gump",
    "Tom Selleck As Magnum P.I.",
    "Val Kilmer As Batman"
],
"Title": [
    "A Christmas Carol",
    "A Few Good Men",
    "A Passage To India",
    "A Place In The Sun",
    "A Room With A View",
    "A Soldier's Story",
    "A Star Is Born",
    "A Walk In The Clouds",
    "Ace Ventura When Nature Calls",
    "Adam's Rib",
    "Addams Family Values",
    "Airport",
    "Alice's Adventures In Wonderland",
    "Alien Nation",
    "All That Jazz",
    "All's Well That Ends Well",
    "Amadeus",
    "American Gothic",
    "An American Tail",
    "An Affair To Remember",
    "Angels In The Outfield",
    "Animal Farm",
    "Another World",
    "Are You Lonesome Tonight",
    "Baby It's You",
    "Back In The Saddle Again",
    "Barnaby Jones",
    "Barney Miller",
    "Barney & Friends",
    "Batman Forever",
    "Baywatch",
    "Blackboard Jungle",
    "Blame It On Rio",
    "Bless The Beasts And The Children",
    "Blue Hawaii",
    "Body Heat",
    "Body Of Evidence",
    "Braveheart",
    "Breakfast At Tiffany's",
    "Breaking Up Is Hard To Do",
    "Breathless",
    "Bright Lights Big City",
    "Cabaret",
    "Caesar And Cleopatra",
    "Calendar Girl",
    "California Girls",
    "Call Of The Wild",
    "Camelot",
    "Can You Feel The Love Tonight",
    "Caroline In The City",
    "Charles In Charge",
    "Charlie's Angels",
    "Charlotte's Web",
    "Chicago Hope",
    "Chinatown",
    "Citizen Kane",
    "City Slickers",
    "Clear And Present Danger",
    "Cliffhanger",
    "Coal Miner's Daughter",
    "Columbo",
    "Coming Home",
    "Cool Runnings",
    "Corinna Corinna",
    "Coward Of The County",
    "Cybill",
    "Dangerous Liaisons",
    "Dangerous Minds",
    "Dave's World",
    "Death Be Not Proud",
    "Deliverance",
    "Demolition Man",
    "Dick Tracy",
    "Die Hard With A Vengeance",
    "Dinosaurs",
    "Dirty Harry",
    "Doctor Dolittle",
    "Dog Day Afternoon",
    "Don't Drink The Water",
    "Downhill Racer",
    "Dr. Kildare",
    "Dr. Quinn Medicine Woman",
    "Dream On",
    "Driving Miss Daisy",
    "East Of Eden",
    "East Side West Side",
    "Eight Is Enough",
    "Eleanor And Franklin",
    "Escape From New York",
    "Evening At Pops",
    "Falcon Crest",
    "Falling In Love Again",
    "Family Affair",
    "Family Feud",
    "Fantastic Voyage",
    "Father Of The Bride",
    "Five Easy Pieces",
    "Flight Of The Bumblebee",
    "Flipper",
    "Fool For Love",
    "Forbidden Planet",
    "Forrest Gump",
    "Four Weddings And A Funeral",
    "Francis The Talking Mule",
    "Frasier",
    "Free Willy",
    "Full House",
    "Fun With Dick And Jane",
    "Funny Lady",
    "Funny Face",
    "General Hospital",
    "Gentle Ben",
    "Gentleman's Agreement",
    "Get Shorty",
    "Gilligan's Island",
    "Glory Days",
    "Go Ask Alice",
    "Good Morning Vietnam",
    "Goodbye Columbus",
    "Goodbye Norma Jean",
    "Gorillas In The Mist",
    "Grand Hotel",
    "Grease",
    "Groundhog Day",
    "Grumpy Old Men",
    "Hail To The Chief",
    "Hamlet",
    "Hannah And Her Sisters",
    "Happy Trails",
    "Hard Times",
    "Heaven Can Wait",
    "Help Me Make It Through The Night",
    "Here Comes The Bride",
    "Hester Street",
    "High Society",
    "High Noon",
    "Hogan's Heroes",
    "Hollywood Squares",
    "Homicide Life On The Street",
    "Honey I Blew Up The Kid",
    "How The West Was Won",
    "Howard's End",
    "I Am A Fugitive From A Chain Gang",
    "I Dream Of Jeannie",
    "I Love Trouble",
    "I Will Follow Him",
    "I'll Fly Away",
    "I've Got A Lovely Bunch Of Coconuts",
    "If It's Tuesday This Must Be Belgium",
    "In The Heat Of The Night",
    "In The Mood",
    "In The Name Of The Father",
    "Independence Day",
    "Ironside",
    "It Had To Be You",
    "It Takes A Thief",
    "Jack And The Beanstalk",
    "Jonny Quest",
    "Junior",
    "Jurassic Park",
    "Just A Gigolo",
    "Kate And Allie",
    "King Of The Road",
    "Kiss Me Kate",
    "Kiss Of The Spider Woman",
    "Knots Landing",
    "L.A. Law",
    "Lady Sings The Blues",
    "Larry King Live",
    "Lassie Come Home",
    "Last Action Hero",
    "Late Night With Greg Kinnear",
    "Late Show With David Letterman",
    "Law & Order",
    "Leader Of The Pack",
    "Lean On Me",
    "Legal Eagles",
    "Less Than Zero",
    "Let It Be",
    "Let's Dance",
    "Lifestyles Of The Rich And Famous",
    "Like Water For Chocolate",
    "Lilies Of The Field",
    "Little Caesar",
    "Little Giants",
    "Little Man Tate",
    "Little Women",
    "Lonesome Dove",
    "Love Affair",
    "Love American Style",
    "Love And War",
    "Love Of My Life",
    "Main Street",
    "Make Room For Daddy",
    "Manhattan Murder Mystery",
    "Marathon Man",
    "Mary Had A Little Lamb",
    "Masterpiece Theater",
    "Max Headroom",
    "Mayberry R.F.D.",
    "Mchale's Navy",
    "Medical Center",
    "Meet Me In St. Louis",
    "Miami Vice",
    "Mighty Morphin Power Rangers",
    "Milk Money",
    "Money For Nothing",
    "Moon Over Miami",
    "Mortal Kombat",
    "Mr. Roberts",
    "Mr. Saturday Night",
    "Mrs. Doubtfire",
    "Murder One",
    "My Cousin Vinny",
    "My Favorite Martian",
    "My Friend Flicka",
    "My Gal Sal",
    "My Fair Lady",
    "My Heroes Have Always Been Cowboys",
    "My Mother The Car",
    "My Three Sons",
    "Nashville",
    "National Lampoon",
    "Network",
    "Next Stop Greenwich Village",
    "Night Of The Living Dead",
    "Nobody's Fool",
    "Norma Rae",
    "North Dallas Forty",
    "Nothing In Common",
    "Ode To Billie Joe",
    "On Golden Pond",
    "On A Clear Day You Can See Forever",
    "One Day At A Time",
    "One Life To Live",
    "Only The Lonely",
    "Only You",
    "Ordinary People",
    "Our Miss Brooks",
    "Paint Your Wagon",
    "Paper Lion",
    "Patton",
    "Picket Fences",
    "Pillow Talk",
    "Pink Cadillac",
    "Planet Of The Apes",
    "Platoon",
    "Play It Again Sam",
    "Porgy And Bess",
    "Postcards From The Edge",
    "Prelude To A Kiss",
    "Pretty Woman",
    "Private Lives",
    "Prizzi's Honor",
    "Problem Child",
    "Proud Mary",
    "Puff The Magic Dragon",
    "Pulp Fiction",
    "Pulp Fiction",
    "Pygmalion",
    "Quiz Show",
    "Raging Bull",
    "Rear Window",
    "Rebecca",
    "Reservoir Dogs",
    "Ripley's Believe It Or Not",
    "Risky Business",
    "Robin Hood Prince Of Thieves",
    "Rocky",
    "Roman Holiday",
    "Romancing The Stone",
    "Romeo And Juliet",
    "Running On Empty",
    "Saved By The Bell",
    "Scarecrow And Mrs. King",
    "Scent Of A Woman",
    "Sense And Sensibility",
    "Sesame Street",
    "Shall We Dance",
    "She Wore A Yellow Ribbon",
    "Shine On Harvest Moon",
    "Shining Star",
    "Shining Through",
    "Short Cuts",
    "Silver Bells",
    "Sister Act",
    "Six Degrees Of Separation",
    "Sleepless In Seattle",
    "Snow White And The Seven Dwarfs",
    "Some Kind Of Hero",
    "Sophie's Choice",
    "Speed",
    "Stagecoach",
    "Stand By Your Man",
    "Star Search",
    "Star Trek Deep Space Nine",
    "Star Trek Generations",
    "Star Trek Voyager",
    "Stardust Memories",
    "Stargate",
    "Starsky And Hutch",
    "Staying Alive",
    "Still Crazy After All These Years",
    "Stormy Weather",
    "Sunday In The Park",
    "Tales From The Crypt",
    "Taxi Driver",
    "Tender Is The Night",
    "Tender Mercies",
    "Tequila Sunrise",
    "That Girl",
    "The American President",
    "The Apartment",
    "The Bodyguard",
    "The Buddy Holly Story",
    "The Canterbury Tales",
    "The Citadel",
    "The Crying Game",
    "The Diary Of Anne Frank",
    "The Electric Horseman",
    "The Fabulous Baker Boys",
    "The Farmer's Daughter",
    "The Flintstones",
    "The Frugal Gourmet",
    "The Godfather",
    "The Goodbye Girl",
    "The Great Escape",
    "The Greatest Story Ever Told",
    "The Hustler",
    "The Iceman Cometh",
    "The Incredible Hulk",
    "The Incredible Journey",
    "The Jungle Book",
    "The Killing Fields",
    "The Little Rascals",
    "The Luci-Desi Comedy Hour",
    "The Mission",
    "The Money Pit",
    "The Right Stuff",
    "The River Wild",
    "The Santa Clause",
    "The Scarlet Letter",
    "The Shaggy Dog",
    "The Shawshank Redemption",
    "The Simpsons",
    "The Single Guy",
    "The Sound Of Music",
    "The Specialist",
    "The Terminator",
    "The Today Show",
    "The Turning Point",
    "The Unbearable Lightness Of Being",
    "The Verdict",
    "The Wackiest Ship In The Army",
    "The Wonder Years",
    "The X-Files",
    "The Age Of Innocence",
    "The Andy Griffith Show",
    "The Call Of The Wild",
    "The Champ",
    "The Circle Of Life",
    "The Color Of Money",
    "The Color Purple",
    "The Computer Wore Tennis Shoes",
    "The Cosby Show",
    "The Day The Earth Stood Still",
    "The Days And Nights Of Molly Dodd",
    "The Deer Hunter",
    "The Diary Of Anne Frank",
    "The Dirty Dozen",
    "The Gambler",
    "The Grapes Of Wrath",
    "The Green Hornet",
    "The Guns Of Navarone",
    "The Jackie Gleason Show",
    "The Last Boy Scout",
    "The Last Detail",
    "The Last Picture Show",
    "The Last Time I Saw Paris",
    "The Lion King",
    "The Little Prince",
    "The Living End",
    "The Lone Ranger",
    "The Long Goodbye",
    "The Lucy Show",
    "The Main Event",
    "The Man In The Iron Mask",
    "The Man Who Knew Too Much",
    "The Man Who Loved Cat Dancing",
    "The Mask",
    "The Member Of The Wedding",
    "The Mod Squad",
    "The Mommies",
    "The Mouse That Roared",
    "The Naked Truth",
    "The Nanny",
    "The Next Karate Kid",
    "The Night Has A Thousand Eyes",
    "The Nutty Professor",
    "The One That Got Away",
    "The Other Side Of The Mountain",
    "The Outer Limits",
    "The Patty Duke Show",
    "The Price Is Right",
    "The Pride Of The Yankees",
    "The Prince Of Tides",
    "The Real World",
    "The Red Pony",
    "The Sand Pebbles",
    "The Seven Percent Solution",
    "The Spy Who Came In From The Cold",
    "The Spy Who Loved Me",
    "The Sun Also Rises",
    "The Swiss Family Robinson",
    "The Sword In The Stone",
    "The Three Musketeers",
    "The Usual Suspects",
    "The Waltons",
    "The War",
    "The War Of The Roses",
    "The Way We Were",
    "The Wind In The Willows",
    "The Wizard Of Oz",
    "The Year Of Living Dangerously",
    "The Yellow Rose Of Texas",
    "The Young And The Restless",
    "Thelma & Louise",
    "There's No Business Like Show Business",
    "Three Days Of The Condor",
    "Till We Meet Again",
    "Timecop",
    "To Have And Have Not",
    "Tootsie",
    "Top Gun",
    "Top Hat",
    "Torn Between Two Lovers",
    "Troop Beverly Hills",
    "True Confessions",
    "True Lies",
    "Twin Peaks",
    "Twist And Shout",
    "Twister",
    "Two Gentlemen Of Verona",
    "Two Years Before The Mast",
    "Unforgiven",
    "Unsolved Mysteries",
    "Up The Down Staircase",
    "Voodoo Lounge",
    "Voyage To The Bottom Of The Sea",
    "Walking Tall",
    "Waterworld",
    "Weekend At Bernie's",
    "Welcome Back Kotter",
    "What's Eating Gilbert Grape",
    "What's My Line",
    "What's Love Got To Do With It",
    "What's New Pussycat",
    "When Dinosaurs Ruled The Earth",
    "When Harry Met Sally",
    "When Will I Be Loved",
    "When You Wish Upon A Star",
    "Where The Boys Are",
    "While You Were Sleeping",
    "White Men Can't Jump",
    "White Nights",
    "Who Framed Roger Rabbit",
    "Whose Life Is It Anyway",
    "Wild Thing",
    "Witness For The Prosecution",
    "Woman Of The Year",
    "Wonder Woman",
    "Working Girl",
    "Yellow Submarine",
    "You Can't Hurry Love"
],
"Headline": [
    "Bill Clinton Elected For Second Term",
    "Charles & Diana Finalize Divorce",
    "Elvis Enlists In The U.S. Army",
    "Hubble Telescope Sends Dramatic Space Photos",
    "Jfk Jr. Secretly Weds Carolyn Bessette",
    "Madonna Gives Birth To A Baby Girl",
    "Michael Jackson & Lisa Marie Presley Divorce",
    "Sonny Bono Elected Mayor Of Palm Springs",
    "Thousands Log On To The Internet",
    "U.S. Sends Chimp Into Outer Space",
    "Watergate Scandal Forces Nixon To Resign",
    "Yankees Defeat Braves To Win The World Series"
],
"Things": [
    "Action-Adventure Films",
    "Alfalfa Sprouts",
    "Asterisks",
    "Autumn Leaves",
    "Avocados Mangoes & Grapefruit",
    "Bacon And Eggs",
    "Bacon Bits",
    "Bagel With Lox And Cream Cheese",
    "Bartlett Pears",
    "Blueberry Muffins",
    "Boxing Gloves",
    "Bread Crumbs",
    "Breath Mints",
    "Bubbles",
    "Buffalo Chicken Wings",
    "Building Blocks",
    "Candied Yams With Marshmallows",
    "Checkers",
    "Chestnuts",
    "Chocolate Chips",
    "Circles",
    "Civil Rights",
    "Coat And Tie",
    "Coattails",
    "Coffee With Cream And Two Sugars",
    "Collectable Coins",
    "Cowboy Boots & Spurs",
    "Crab Cakes",
    "Crayons",
    "Detailed Descriptions",
    "Dewdrops",
    "Dill Rosemary & Thyme",
    "Dining Room Chairs",
    "Directions",
    "Dirt And Grime",
    "Dirty Dishes",
    "Dog Tags",
    "Dominoes",
    "Double Doors",
    "Economic Indicators",
    "Endangered Species",
    "Espresso Cappuccino & Decaf Coffee",
    "Eyelids",
    "Fangs",
    "Farm Animals",
    "Fiber Optics",
    "Filters",
    "Final Exams",
    "Fireworks",
    "Flames",
    "Flesh And Blood",
    "Footlights",
    "Forget-Me-Nots",
    "Freckles",
    "Fringe Benefits",
    "Funny Papers",
    "Gale Force Winds",
    "Golf Clubs",
    "Goods And Services",
    "Groceries",
    "Guard Dogs",
    "Guest Towels",
    "Hammer And Nails",
    "Hand-Me-Down Clothes",
    "Handcuffs",
    "Hash Brown Potatoes",
    "Hearts Diamonds Clubs & Spades",
    "Hidden Compartments",
    "High Marks",
    "House Keys",
    "Household Hints",
    "Houseplants",
    "Hush Puppies",
    "Illustrations",
    "Incentives",
    "Investments",
    "Jumping Jacks",
    "Kidney Beans",
    "Ladyfingers",
    "Leather Gloves",
    "Limited Resources",
    "Living Room Drapes",
    "Lyrics",
    "Macaroni And Cheese",
    "Missed Opportunities",
    "Mistakes",
    "Morning Exercises",
    "Mountain Climbing Equipment",
    "Municipal Bonds",
    "Mushrooms",
    "Musical Instruments",
    "Napkins",
    "Newspaper Articles",
    "Numbers",
    "Numerator And Denominator",
    "Nursery Rhymes",
    "Nylon Stockings",
    "Office Furniture",
    "Orange Blossoms",
    "Oranges",
    "Overhead Lights",
    "Pancakes",
    "Pies And Tarts",
    "Pine Needles",
    "Pine Nuts",
    "Pink Elephants",
    "Pins And Needles",
    "Plants",
    "Polo Ponies",
    "Prayer Beads",
    "Push Pins",
    "Questions",
    "Radial Tires",
    "Record Books",
    "Reference Books",
    "Regular Examinations",
    "Replacement Parts",
    "Restrictions",
    "Rhinestones",
    "Rice Cakes",
    "Riding Boots",
    "Roman Numerals",
    "Saddle Bags",
    "Sale Merchandise",
    "Salt And Pepper",
    "Sand Dunes",
    "Sandals",
    "Sandy Beaches",
    "Saplings",
    "Scallions",
    "Scallops",
    "Seashells",
    "Shampoo & Conditioner",
    "Sideburns",
    "Sled Dogs",
    "Soybeans",
    "Spade Shovel & Hoe",
    "Spare Parts",
    "Stained Glass Windows",
    "Standard Requirements",
    "Statistics",
    "Stereo Components",
    "Streamers",
    "Student Lectures",
    "Sugar Cubes",
    "Syllables",
    "Tax Deductions",
    "Telephone Directories",
    "Television Networks",
    "Toothpicks",
    "Tree Branches",
    "Tropical Flowers",
    "Twin Rollaway & Double Beds",
    "Used Automobiles",
    "Vegetables",
    "Verbal Commands",
    "Vital Statistics",
    "Vitamins And Minerals",
    "Watercolors",
    "Weather Forecasts",
    "Weeks And Months",
    "Wild Beasts",
    "Wild Horses",
    "Wooden Shoes",
    "Written Estimates",
    "Yellow Daisies",
    "Zoo Animals"
],
"Artist & Song": [
    "Barbra Streisand's Memory",
    "Barbra Streisand's The Way We Were",
    "Billy Joel's The Piano Man",
    "Bing Crosby's White Christmas",
    "Bob Hope's Thanks For The Memory",
    "Bruce Springsteen's Born In The USA",
    "Elton John's Goodbye Yellow Brick Road",
    "Frank Sinatra's My Way",
    "James Taylor's Yo've Got A Friend",
    "John Lennon's Imagine",
    "Judy Garland's Over The Rainbow",
    "Liza Minelli's New York New York",
    "Louis Armstrong's Hello Dolly",
    "Paul Simon's Slip Slidin' Away",
    "The Beatles' Hey Jude",
    "The Village People's YMCA",
    "Whitney Houston's I Will Always Love You"
],
"Fictional Character": [
    "Aphrodite",
    "Babar King Of The Elephants",
    "Batman",
    "Betty Rubble",
    "Bugs Bunny",
    "Count Dracula",
    "Daffy Duck",
    "Elmer Fudd",
    "Flash Gordon",
    "Huckleberry Finn",
    "Indiana Jones",
    "Jack Be Nimble",
    "Johnny Appleseed",
    "Lady Macbeth",
    "Leprechaun",
    "Little Red Riding Hood",
    "Mother Goose",
    "Nancy Drew",
    "Olive Oyl",
    "Papa Bear",
    "Perry Mason",
    "Pocahontas",
    "Popeye The Sailor Man",
    "Quick-Draw McGraw",
    "Rip Van Winkle",
    "Simba",
    "Simple Simon",
    "Snow White",
    "The Cheshire Cat",
    "The Frog Prince",
    "The Sandman",
    "The Sheriff Of Nottingham",
    "The Glass Menagerie's Gentleman Caller",
    "The Man In The Moon",
    "Tiny Tim",
    "Tom Sawyer",
    "Unicorn",
    "Walt Kelly's Pogo The Possum",
    "Wee Willie Winkie",
    "Wilma Flintstone",
    "Wise Old Owl",
    "Yosemite Sam"
],
"The Seventies": [
    "Apple Starts Producing Personal Computers",
    "Egypt & Israel Sign Historic Peace Treaty",
    "Evita & A Chorus Line Are Broadway Hits",
    "First Test-Tube Baby Born",
    "Mark Spitz Wins Seven Olympic Gold Medals",
    "The U.S. Celebrates Its Bicentennial",
    "U.S. Signs Treaty Returning Panama Canal"
],
"Show Biz": [
    "Audrey Hepburn Has Breakfast At Tiffany's",
    "Bob Hope Entertains The Troops",
    "Bob Hope & Bing Crosby Star In Road Movies",
    "Comic Relief Farm Aid & Live Aid",
    "Late Night Talk Show Wars",
    "Paramount & Warner Brothers Start TV Networks",
    "Sylvester Stallone Makes Five Rocky Movies",
    "The Beatles Appear On The Ed Sullivan Show",
    "The Muppets Get Their Own TV Show"
],
"The Sixties": [
    "Lyndon Johnson Re-Elected As President",
    "Medicare Provides Aid To The Elderly",
    "National Organization For Women Founded",
    "Soviets Erect Berlin Wall",
    "Thousands Attend Concert At Woodstock"
],
"Classic TV": [
    "Charlie Brown & Snoopy Come To Television",
    "Gilligan & Friends Take A Three-Hour Tour",
    "Gunsmoke Rawhide & Bonanza",
    "How Sweet It Is",
    "I'm So Glad We Had This Time Together",
    "Jack Webb Stars In Dragnet",
    "Lassie & Flipper",
    "Lucy & Ethel Get Into Trouble On I Love Lucy",
    "Mork & Mindy",
    "My Favorite Martian",
    "Oh I Wish I Were An Oscar Mayer Weiner",
    "See The USA In Your Chevrolet",
    "Sid Caesar & Imogene Coca In Your Show Of Shows",
    "Star Trek & Lost In Space",
    "The Jetsons & The Flintstones",
    "The Lone Ranger & Tonto",
    "The Munsters & The Addams Family",
    "Wheel Of Fortune Debuts On Nighttime Television"
],
"Same Name": [
    "Barnaby & Me And Mrs Jones",
    "Barney & Mitch Miller",
    "Bird's & Empty Nest",
    "Breaking & I'll Fly Away",
    "Cat On A Hot Tin & Fiddler On The Roof",
    "Clean-Up & Pancake Batter",
    "Death & Lily Of The Valley",
    "Designing & Little Women",
    "Dog Day & Sunday Afternoon",
    "Eager & Leave It To Beaver",
    "Ella & F. Scott Fitzgerald",
    "Ellis & Fantasy Island",
    "Evening & Window Shade",
    "Fantasy & Gilligan's Island",
    "Flower And Taste Buds",
    "Foul & One-Act Play",
    "Full & Open House",
    "George & Burning Bush",
    "Gilligan's & Treasure Island",
    "Glory & Happy Days",
    "Golf & Cuff Links",
    "Good Morning & North America",
    "Groucho & Karl Marx",
    "Head Over & High Heels",
    "Helen & Sea Hunt",
    "Highway To & Pennies From Heaven",
    "Hugh & Churchill Downs",
    "Human & Mother Nature",
    "Japanese & Volkswagen Beetle",
    "Johnny & Kit Carson",
    "Key & Adam West",
    "Knots & Moon Landing",
    "Liberty & Alexander Graham Bell",
    "Michael & New York",
    "Mister & Kenny Rogers",
    "Monty & Annie Hall",
    "Murphy & James Brown",
    "Natalie & Old King Cole",
    "Neck & Family Ties",
    "Night & Order In The Court",
    "Panama & Root Canal",
    "Piccadilly & Three-Ring Circus",
    "Pool & Great White Shark",
    "President James & Marilyn Monroe",
    "Rodeo & Midnight Cowboy",
    "Root Beer & Orange Bowl Parade Floats",
    "Roy Will & Kenny Rogers",
    "Spike & Robert E. Lee",
    "Sweet & Field Of Dreams",
    "The Deer & Holly Hunter",
    "The Lone & Park Ranger"
],
"Author & Title": [
    "For Whom The Bell Tolls By Ernest Hemingway",
    "Pride & Prejudice By Jane Austen",
    "Tales Of The South Pacific By James Michener",
    "The Great Gatsby By F. Scott Fitzgerald",
    "The Hunt For Red October By Tom Clancy",
    "The Right Stuff By Tom Wolfe",
    "The Tale Of Peter Rabbit By Beatrix Potter",
    "The World According To Garp By John Irving"
],
"Song/Show": [
    "A Whole New World From Aladdin",
    "Colors Of The World From Pocahontas",
    "Don't Cry For Me Argentina From Evita",
    "Getting To Know You From The King And I",
    "I Could Have Danced All Night From My Fair Lady",
    "I Feel Pretty From West Side Story",
    "Memory From Cats",
    "Under The Sea From The Little Mermaid",
    "What I Did For Love From A Chorus Line"
],
"Husband & Wife": [
    "Al & Tipper Gore",
    "Arnold Schwarzenegger & Maria Shriver",
    "Bill & Hillary Rodham Clinton",
    "Bruce Willis & Demi Moore",
    "George & Barbara Bush",
    "Jimmy & Rosalynn Carter",
    "John Travolta & Kelly Preston",
    "John F. Kennedy Jr. & Carolyn Bessette",
    "Paul Newman & Joanne Woodward",
    "Queen Elizabeth & Prince Philip",
    "Ronald & Nancy Reagan",
    "Steven Spielberg & Kate Capshaw",
    "Ted Turner & Jane Fonda",
    "Warren Beatty & Annette Bening"
],
"Nickname": [
    "Billy The Kid",
    "Calamity Jane",
    "Ivan The Terrible",
    "Legs Diamond",
    "Long John Silver",
    "Merry Old England",
    "Miracle Mile",
    "Old Ironsides",
    "Old Man Rhythm",
    "Paddy Wagon",
    "Peter The Great",
    "The Emerald Isle",
    "The Fourth Estate",
    "The City Of Brotherly Love",
    "The Land Of Plenty",
    "The Roaring Twenties",
    "The Wild West",
    "Tin Pan Alley",
    "Whirlybird"
],
"Quotation": [
    "A Bicycle Built For Two",
    "A Legend In His Own Time",
    "A Pocket Full Of Posies",
    "A Poem Lovely As A Tree",
    "A Rolling Stone Gathers No Moss",
    "A Yankee Doodle Do Or Die",
    "All I Have To Do Is Dream",
    "Baby We Were Born To Run",
    "Big Wheels Keep On Turning",
    "Bring Back My Bonny To Me",
    "Bringing In The Sheaves",
    "Clang Clang Clang Went The Trolley",
    "Curses Foiled Again",
    "Deck The Halls With Boughs Of Holly",
    "Deep In The Heart Of Texas",
    "Do The Twist",
    "Doe A Deer A Female Deer",
    "Don't Tread On Me",
    "Four Score And Seven Years Ago",
    "From The Mountains To The Prairies",
    "Gently Down The Stream",
    "Give Us This Day Our Daily Bread",
    "Goodness Gracious Great Balls Of Fire",
    "He's Making A List And Checking It Twice",
    "Healthy Wealthy And Wise",
    "Here We Go Round The Mulberry Bush",
    "Hey Diddle Diddle The Cat And The Fiddle",
    "Hickory Dickory Dock",
    "How Deep Is Your Love",
    "How Do You Spell Relief",
    "How Sweet It Is",
    "I Came I Saw I Conquered",
    "I Cannot Tell A Lie",
    "I Cannot Tell A Lie",
    "I Pledge Allegiance To The Flag",
    "I'm In The Mood For Love",
    "It's A Long Way To Tipperary",
    "Like Sands Through The Hourglass",
    "Little Boy Blue Come Blow Your Horn",
    "Love Thy Neighbor",
    "Love To Love You Baby",
    "Mary Had A Little Lamb",
    "Miles To Go Before I Sleep",
    "My Cup Runneth Over",
    "Never Trust Anyone Over Thirty",
    "No Man Is An Island",
    "No Way To Treat A Lady",
    "O'er The Ramparts We Watched",
    "Oh You Beautiful Doll",
    "Once Upon A Time",
    "Only The Shadow Knows",
    "Pocket Full Of Posies",
    "Rally 'Round The Flag Boys",
    "Reach Out And Touch Someone",
    "Root Root Root For The Home Team",
    "Row Row Row Your Boat",
    "See Spot Run",
    "Seek And Ye Shall Find",
    "Some Guys Have All The Luck",
    "Take My Wife Please",
    "Teach Your Children Well",
    "Thanks For The Memory",
    "The Farmer Takes A Wife",
    "The Fog Comes In On Little Cat Feet",
    "The Meek Shall Inherit The Earth",
    "The Shot Heard Round The World",
    "This Land Was Made For You And Me",
    "Tie A Yellow Ribbon",
    "To Err Is Human To Forgive Divine",
    "To Form A More Perfect Union",
    "Twinkle Twinkle Little Star",
    "We Have Met The Enemy And He Is Us",
    "What's Good For The Goose Is Good For The Gander",
    "When In The Course Of Human Events",
    "Where Seldom Is Heard",
    "Wherefore Art Thou Romeo",
    "Workers Of The World Unite"
],
"The Eighties": [
    "East & West Germany Reunite",
    "John McEnroe Wins Three Wimbledon Titles",
    "MTV Debuts All-Music Format",
    "The Soviet Union Collapses"
],
"Places": [
    "Baggage Claim Areas",
    "Canadian Provinces",
    "Canary Islands",
    "Churches & Synagogues",
    "Islands Of The West Indies",
    "Northern & Southern Suburbs",
    "Samoan Islands",
    "School Zones",
    "Southern States",
    "The Florida Keys",
    "The Windward Islands",
    "The Four Corners Of The Earth",
    "Virgin Islands"
],
"Person - Proper Name": [
    "Abraham Lincoln",
    "Actor Director Clint Eastwood",
    "Actor Ernest Borgnine",
    "Actress Comedian Whoopi Goldberg",
    "Actress Dana Delaney",
    "Actress Heather Locklear",
    "Adlai Stevenson",
    "Al Gore",
    "Albert Einstein",
    "Aldous Huxley",
    "Ambrose Bierce",
    "Anatole France",
    "Andy Rooney",
    "Andy Warhol",
    "Anita Baker",
    "Ann Jillian",
    "Annette Bening",
    "Architect Frank Lloyd Wright",
    "Art Linkletter",
    "Astronaut John Glenn",
    "Astronomer Galileo",
    "Attorney General Janet Reno",
    "Author Herman Melville",
    "Author James Thurber",
    "Aviator Charles Lindbergh",
    "Beatrix Potter",
    "Bertrand Russell",
    "Bill Clinton",
    "Bruce Jenner",
    "Bruce Willis",
    "Calvin Coolidge",
    "Cleopatra",
    "Clint Eastwood",
    "Comedian Ellen Degeneres",
    "Comedian George Carlin",
    "Composer George Gershwin",
    "Country Singer Johnny Cash",
    "Dan Quayle",
    "Daniel Boone",
    "Davy Crockett",
    "Drew Barrymore",
    "Dustin Hoffman",
    "Dwight D. Eisenhower",
    "Dwight Yoakam",
    "Elvis Presley",
    "Eric Clapton",
    "Ernest Borgnine",
    "Fashion Designer Giorgio Armani",
    "Film Director John Huston",
    "Flip Wilson",
    "Florence Nightingale",
    "Former First Lady Barbara Bush",
    "Franklin Delano Roosevelt",
    "George Bernard Shaw",
    "George Bush",
    "George Gershwin",
    "George Washington",
    "Gerald Ford",
    "Giorgio Armani",
    "Godfather Of Soul James Brown",
    "Grandma Moses",
    "Grover Cleveland",
    "Harrison Ford",
    "Harry S Truman",
    "Helen Of Troy",
    "Henry Fonda",
    "Herbert Hoover",
    "Home Improvement Star Tim Allen",
    "Horatio Alger",
    "Indira Gandhi",
    "J. Edgar Hoover",
    "Jack Nicholson",
    "Jackie Gleason",
    "James Dean",
    "Jenny Jones",
    "Jimmy Carter",
    "John Adams",
    "John Barrymore",
    "John Hancock",
    "Jonathan Swift",
    "Julius Caesar",
    "Karl Marx",
    "Leading Lady Mae West",
    "Leading Man Harrison Ford",
    "Lenny Kravitz",
    "Leonardo Da Vinci",
    "Lord Byron",
    "Luciano Pavarotti",
    "Luther Vandross",
    "Lyndon Baines Johnson",
    "Magician David Copperfield",
    "Marilyn Monroe",
    "Martin Luther King",
    "Mary Chapin Carpenter",
    "Melissa Etheridge",
    "Meryl Streep",
    "Mother Teresa",
    "Napoleon Bonaparte",
    "Neil Young",
    "New York Mayor Rudolph Giuliani",
    "News Correspondent Charles Kuralt",
    "Norman Rockwell",
    "Novelist Jack London",
    "Oliver North",
    "Orson Welles",
    "Patty Hearst",
    "Paul Newman",
    "Paul Revere",
    "Peter Gabriel",
    "Phil Donahue",
    "Placido Domingo",
    "Poet Carl Sandburg",
    "President Calvin Coolidge",
    "Prince Rainier Of Monaco",
    "Randy Quaid",
    "Revolutionary Leader John Hancock",
    "Richard Nixon",
    "Robert Stack",
    "Rock Musician Sting",
    "Roseanne",
    "Rosie O'Donnell",
    "Rush Limbaugh",
    "Sam Snead",
    "Scientist Albert Einstein",
    "Sheryl Crow",
    "Singer Bonnie Raitt",
    "Singer Toni Braxton",
    "Socrates",
    "Speaker Of The House Newt Gingrich",
    "Superstar Elton John",
    "Talk Show Host Phil Donahue",
    "Ted Turner",
    "The Dalai Lama",
    "Theodore Roosevelt",
    "Thomas Jefferson",
    "Tom Jones",
    "Tony Bennett",
    "Van Morrison",
    "Warren Beatty",
    "Whoopi Goldberg",
    "Will Rogers",
    "William Shakespeare",
    "Winston Churchill",
    "Woodrow Wilson",
    "Wynonna Judd",
    "Yoko Ono",
    "Zsa Zsa Gabor"
],
"Person": [
    "A Good Soldier",
    "A Handsome Man",
    "A Mature Individual",
    "A Mere Child",
    "A Pain In The Neck",
    "A Professor With Tenure",
    "A Real Crowd-Pleaser",
    "A Real Looker",
    "Acquaintance",
    "Administrator",
    "Angel",
    "Archer",
    "Artist",
    "Aunt",
    "Best Man",
    "Bishop",
    "Blue Blood",
    "Bride",
    "Bridesmaid",
    "British Citizen",
    "Brother",
    "Brother-In-Law",
    "Business Associate",
    "Business Partner",
    "Bystander",
    "Candidate",
    "Cattle Rustler",
    "Client",
    "Co-Worker",
    "Coloratura Soprano",
    "Comedian",
    "Commander In Chief",
    "Commanding Officer",
    "Common-Law Husband",
    "Computer Hacker",
    "Con Artist",
    "Constituent",
    "Copy Cat",
    "Cousin",
    "Crowd-Pleaser",
    "Crybaby",
    "Cub Reporter",
    "Deacon",
    "Dean Of Students",
    "Department Head",
    "Devoted Husband",
    "Diplomat",
    "Doctor Of Philosophy",
    "Double Agent",
    "Drama Student",
    "Drifter",
    "Elder Statesman",
    "England's Queen Mother",
    "Equestrian",
    "Ex-Wife",
    "Executive",
    "Expert Witness",
    "Fair-Weather Friend",
    "Father",
    "First Cousin",
    "Fisherman",
    "Foot Soldier",
    "Football Tackle",
    "Fortune Hunter",
    "Friend Of The Family",
    "Gardener",
    "Genius",
    "Gentleman",
    "Globe Trotter",
    "Good Samaritan",
    "Government Official",
    "Grandfather",
    "Horseback Rider",
    "Host Of A Party",
    "Independent Investor",
    "Insider",
    "Johnny-Come-Lately",
    "Juvenile",
    "Lame Duck President",
    "Landlubber",
    "Landowner",
    "Leader Of The Band",
    "Legal Occupant",
    "Lieutenant Colonel",
    "Light Sleeper",
    "Local Hero",
    "Lounge Singer",
    "Major General",
    "Manager",
    "Matron",
    "Middleman",
    "Minor",
    "Monday Morning Quarterback",
    "Most Likely To Succeed",
    "Mother",
    "Mother Of The Bride",
    "Native American Shaman",
    "Nephew",
    "Niece",
    "Night Owl",
    "Nobel Prize Winner",
    "Officer Of The Court",
    "Opponent",
    "Optimist",
    "Original Owner",
    "Outlaw",
    "Patriot",
    "People-Watcher",
    "Pessimist",
    "Philosopher",
    "Platoon Leader",
    "Platoon Sergeant",
    "Player Of The Year",
    "Pre-Med Student",
    "Priest",
    "Prophet",
    "Proprietor",
    "Protagonist",
    "Publisher",
    "Reader",
    "Redhead",
    "Renaissance Man",
    "Representative",
    "Rodeo Cowboy",
    "Roman Gladiator",
    "Rookie Of The Year",
    "Runner-Up",
    "Scapegoat",
    "Schoolboy",
    "Scoundrel",
    "Screwball",
    "Second Cousin",
    "Shareholder",
    "Shipwrecked Sailor",
    "Shrinking Violet",
    "Significant Other",
    "Silent Partner",
    "Sister",
    "Sister-In-Law",
    "Skin Diver",
    "Sleepyhead",
    "Sob Sister",
    "Soft Touch",
    "Sophomore",
    "Soprano",
    "Sorority Sister",
    "Southern Belle",
    "Spanish Senorita",
    "Sports Fan",
    "Spouse",
    "Staff Member",
    "Staff Sergeant",
    "Star Of Stage And Screen",
    "State Trooper",
    "Stepfather",
    "Stockholder",
    "Storyteller",
    "Student Teacher",
    "Substitute Teacher",
    "Supervisor",
    "Taxpayer",
    "Teaching Fellow",
    "Tenderfoot",
    "Tenor",
    "The Duke Of York",
    "The Prince Of Wales",
    "Ticket Scalper",
    "Tomboy",
    "Tourist",
    "Traitor",
    "Trustee",
    "Tyrant",
    "Umpire",
    "Uncle",
    "Ventriloquist",
    "Very Important Person",
    "Veteran",
    "Violinist",
    "Virtuoso",
    "Weight-Lifter",
    "Young Man"
],
"Before & After": [
    "A Blast From The Past Tense",
    "A Long Shot In The Dark",
    "A Marked Man Of The World",
    "A Touch Of Class Clown",
    "Abraham Lincoln Continental",
    "Adam's Apple Pie",
    "Against All Odds Or Evens",
    "Agatha Christie Brinkley",
    "Alexander The Great Balls Of Fire",
    "All The World's A Stage Fright",
    "American Red Cross Your Heart",
    "An Ear Of Corn Syrup",
    "Baking Soda Fountain",
    "Baton Rouge Louisiana Purchase",
    "Beat The Odds And Ends",
    "Benjamin Franklin D. Roosevelt",
    "Betsy Ross Perot",
    "Billie Jean King Of The Road",
    "Billy Joel Grey",
    "Block That Kick In The Pants",
    "Blow Off A Little Steam Engine",
    "Carrie Fisher-Price",
    "Carrying A Torch Song Trilogy",
    "Central Park Avenue",
    "Charlie Brown Bear",
    "Cleopatra's Barge In On",
    "Coat Of Paint By Numbers",
    "Cost Of Living Well Is The Best Revenge",
    "Cover Girl Scout",
    "Dallas Cowboys And Indians",
    "Debbie Reynolds Wrap",
    "Dolley Madison Square Garden",
    "Don't Fence Me In The Mood",
    "Down In The Valley Forge",
    "Down The Hatch An Egg",
    "Eggs Over Easy Come Easy Go",
    "Emerald Green Bay Packers",
    "Emily Post Office Box",
    "Empty Space Shuttle",
    "Fast Food For Thought",
    "Fat Lip Gloss",
    "Fine Art Carney",
    "Floor Mats Wilander",
    "Flower Power Lunch",
    "Fort Worth Its Weight In Gold",
    "Francis Scott Key West Florida",
    "Free Throw Rug",
    "Gentle Ben Vereen",
    "Get Lost And Found",
    "Glad Rags To Riches",
    "Glory Days Of Our Lives",
    "Golden Gate Bridge Game",
    "Gone With The Wind Tunnel",
    "Gourmet Food For Thought",
    "Grace Kelly Green",
    "Grace Under Fire Alarm",
    "Grover Cleveland Ohio",
    "Hail To The Chief Executive Officer",
    "Harry S Truman Capote",
    "Hedge Your Bet Your Life",
    "Here's Mud In Your Eye Of The Needle",
    "Here's Mud In Your Eye Shadow",
    "Hit Or Miss Saigon",
    "Holy Roman Empire State Building",
    "How Could You Dirty Rat",
    "Hubert Humphrey Bogart",
    "Hundred-Dollar Bill Clinton",
    "I Miss You Dirty Rat",
    "In The Mood Swings",
    "India Ink-Jet Printer",
    "It Boggles The Mind Your Own Business",
    "Jack London England",
    "Japanese Beetle Bailey",
    "Jerry Lewis & Clark",
    "Jesse James Michener",
    "Jodie Foster Parents",
    "Joe Louis Armstrong",
    "John Denver Colorado",
    "John Glenn Close",
    "Johnny Carson City Nevada",
    "Judgment Call Of The Wild",
    "Julius Caesar Salad",
    "Kate Jackson Five",
    "Kelly Green Acres",
    "King Of The Road Warrior",
    "Lag Behind The Eight Ball",
    "Leap Of Faith Hope And Charity",
    "Let There Be Light Bulb",
    "Little Orphan Annie Potts",
    "Little Boy Blue Ribbon",
    "Little House On The Prairie Dog",
    "Lloyd Bridges Of Madison County",
    "Lone Star State Of The Union",
    "Love Me Tender Mercies",
    "Lunch Date Palm Tree",
    "Maid Marian The Librarian",
    "Mail Call Of The Wild",
    "Martha Graham Crackers",
    "Master Key Largo",
    "Meet The Press Your Luck",
    "Melrose Place Your Bets",
    "Mess Kit Carson",
    "Minnie Pearl Harbor",
    "Miss Piggy Bank",
    "Moby Dick Tracy",
    "Money Order In The Court",
    "Murphy Brown University",
    "Nancy Drew Barrymore",
    "No Way To Treat A Lady Bird Johnson",
    "Nolan Ryan O'Neal",
    "On The Make Your Move",
    "Order In The Court Jester",
    "Patrick Henry The Eighth",
    "Piccadilly Circus Clown",
    "Plain Jane Eyre",
    "Porgy And Bess Truman",
    "Port Of Call Waiting",
    "Puget Sound Off",
    "Rain Man Of The World",
    "Ralph Lauren Bacall",
    "Ray Charles In Charge",
    "Rich Little House On The Prairie",
    "Ricki Lake Superior",
    "Ricki Lake Worth Florida",
    "Rise And Shine My Shoes",
    "Rob Roy Rogers",
    "Robert Frost On The Pumpkin",
    "Room At The Top Of The Morning",
    "Saint Francis Scott Key",
    "Sally Field Of Dreams",
    "Sam Houston Oilers",
    "Santa Barbara Walters",
    "Scrub The Floor Show",
    "Searching High And Low Tide",
    "Shelley Long Underwear",
    "Shirley Temple University",
    "Shopping Basket Case",
    "Sinclair Lewis & Clark",
    "Sir Walter Raleigh North Carolina",
    "Sir Walter Scott Joplin",
    "Sitting Pretty Please With Sugar On It",
    "Skating On Thin Ice Cream Cone",
    "Sleeping Beauty And The Beast",
    "Sports Car Wash",
    "Stephen King Kong",
    "Steve Martin Short",
    "Susan B. Anthony Hopkins",
    "Swan Lake Erie",
    "Take Five Easy Pieces",
    "Take It Easy Rider",
    "Tennis Elbow Grease",
    "The Brady Bunch Of Grapes",
    "The British Open Wide",
    "The Right Stuff And Nonsense",
    "Theodore Roosevelt Grier",
    "Thomas Jefferson Davis",
    "Toe The Mark Twain",
    "Tootsie Roll Of Quarters",
    "Tower Of London Bridge",
    "West Point Of View",
    "When You Wish Upon A Star Trek",
    "Whitney Houston Texas"
],
"Place": [
    "Aberdeen Scotland",
    "Adriatic Sea",
    "Aegean Sea",
    "Africa",
    "Albania",
    "Albuquerque New Mexico",
    "Allentown",
    "Amarillo Texas",
    "Amazon Region Of Brazil",
    "Amherst College",
    "Amphitheatre",
    "Amsterdam",
    "Anaheim California",
    "Angola",
    "Anguilla",
    "Appalachia",
    "Arlington Virginia",
    "Armenia",
    "Aruba",
    "Aspen Colorado",
    "Atlanta Georgia",
    "Austria",
    "Babylon",
    "Baghdad",
    "Bakersfield California",
    "Baltimore Maryland",
    "Bangladesh",
    "Bangor Maine",
    "Barbados",
    "Baton Rouge",
    "Bavaria",
    "Beauty Salon",
    "Bedroom",
    "Beijing China",
    "Belgrade",
    "Berkeley California",
    "Bern Switzerland",
    "Bethlehem",
    "Bonn Germany",
    "Borneo",
    "Boston's Fenway Park",
    "Bowling Alley",
    "Brighton England",
    "Brisbane Australia",
    "Bristol England",
    "Brittany France",
    "Broadway",
    "Brown University",
    "Bucharest Romania",
    "Buffalo New York",
    "Bulgaria",
    "Bunker Hill",
    "Burgundy Region Of France",
    "Cairo Egypt",
    "Calcutta India",
    "Cambridge",
    "Camden New Jersey",
    "Cardiff Wales",
    "Castle",
    "Charleston South Carolina",
    "Chicago's Loop",
    "Chile",
    "Chinatown",
    "Classroom",
    "Cleveland Ohio",
    "Clothes Closet",
    "College Dorm",
    "Cologne",
    "Colombia",
    "Columbia University",
    "Copper Mine",
    "Coral Reef",
    "Cornell University",
    "Corvallis Oregon",
    "Country Club",
    "County Seat",
    "Courtroom",
    "Coventry England",
    "Cycle Shop",
    "Danbury Connecticut",
    "Dartmouth College",
    "Dayton Ohio",
    "Daytona Beach Florida",
    "Dearborn Michigan",
    "Decatur Georgia",
    "Denver",
    "Deserted Island",
    "Disneyland",
    "Djakarta",
    "Dominican Republic",
    "Doorway",
    "Down On The Farm",
    "Downtown",
    "Duluth Minnesota",
    "Dungeon",
    "Durham North Carolina",
    "Dusseldorf",
    "Dwelling",
    "East Hampton Long Island",
    "El Salvador",
    "England",
    "Englewood New Jersey",
    "Erie Canal",
    "Estonia",
    "Eugene Oregon",
    "Europe",
    "Evanston Illinois",
    "Fairfield Connecticut",
    "Fairgrounds",
    "Fairway",
    "Family Farm",
    "Filling Station",
    "Florida Everglades",
    "Fordham University",
    "Formosa",
    "Fort Leavenworth",
    "Frankfort Kentucky",
    "Frankfurt Germany",
    "Freeport Bahamas",
    "Fresno California",
    "Gainesville Florida",
    "Gallup New Mexico",
    "Garage",
    "Gas Station",
    "Genoa Italy",
    "Georgetown",
    "Germany",
    "Gettysburg",
    "Gettysburg National Military Park",
    "Ghana",
    "Gibraltar",
    "Glendale California",
    "Gloucester",
    "Grade School",
    "Granada Spain",
    "Grand Cayman",
    "Great Bear Lake Canada",
    "Great Britain",
    "Greece",
    "Green Room",
    "Grenada",
    "Hamburg Germany",
    "Harbor",
    "Harlem",
    "Harrisburg",
    "Hartford Connecticut",
    "Hattiesburg Mississippi",
    "Heidelberg Germany",
    "Hermosa Beach California",
    "Highway Rest Stop",
    "Hiroshima Japan",
    "Hoboken New Jersey",
    "Holland",
    "Hollywood",
    "Hometown",
    "Hospital",
    "Hotel Room",
    "Hotel Suite",
    "Houston Texas",
    "Hungary",
    "Hunting Lodge",
    "Ice Rink",
    "Iceland",
    "India",
    "Indochina",
    "Inverness Scotland",
    "Irvine California",
    "Italy",
    "Ithaca New York",
    "Jamestown Virginia",
    "Jericho",
    "Joe Robbie Stadium In Miami",
    "Joliet Illinois",
    "Junior High School",
    "Kabul Afghanistan",
    "Key Largo Florida",
    "Key West Florida",
    "Khartoum Sudan",
    "Kuwait",
    "Kyoto Japan",
    "Lafayette Louisiana",
    "Lake Huron",
    "Lake Erie",
    "Lakehurst Naval Air Station",
    "Lancaster",
    "Lansing Michigan",
    "Laredo Texas",
    "Leeds England",
    "Library",
    "Libya",
    "London's Hyde Park",
    "London's Mayfair District",
    "Los Angeles",
    "Los Alamos New Mexico",
    "Lucerne Switzerland",
    "Lyon France",
    "Madison Avenue",
    "Madrid Spain",
    "Managua Nicaragua",
    "Manhattan",
    "Manila Philippines",
    "Manitoba Canada",
    "Marin County California",
    "Martha's Vineyard",
    "Mesopotamia",
    "Miami Florida",
    "Michigan's Upper Peninsula",
    "Micronesia",
    "Middletown Connecticut",
    "Milwaukee Wisconsin",
    "Minnesota",
    "Modesto California",
    "Monaco",
    "Montclair New Jersey",
    "Montenegro",
    "Monticello",
    "Montserrat",
    "Morocco",
    "Moscow's Red Square",
    "Mount Holyoke College",
    "Mount Shasta",
    "Movie Theater",
    "Muncie Indiana",
    "Munich Germany",
    "Naples Florida",
    "Nassau",
    "Natchez Mississippi",
    "Nazareth",
    "Never-Never Land",
    "Nevis West Indies",
    "New Jersey",
    "New Orleans Louisiana",
    "New Jersey Turnpike",
    "New York Thruway",
    "New York's Central Park",
    "New York's Harlem",
    "New York's Hudson River",
    "New York's Lake Chautauqua",
    "New York's Lake Onondaga",
    "New York's Westchester County",
    "Norfolk Virginia",
    "Normandy",
    "Norwalk Connecticut",
    "Nursery School",
    "Observation Booth",
    "Ogden Utah",
    "Olympia Washington",
    "Omaha Nebraska",
    "Orlando Florida",
    "Oshkosh Wisconsin",
    "Oxford Mississippi",
    "Oxnard California",
    "Palermo Sicily",
    "Palestine",
    "Palm Beach",
    "Palm Springs",
    "Paris France",
    "Park Place",
    "Patagonia",
    "Peninsula",
    "Pennsylvania Dutch Country",
    "Penthouse",
    "Peoria Illinois",
    "Permanent Residence",
    "Perth Australia",
    "Phone Booth",
    "Pittsburgh",
    "Plainfield New Jersey",
    "Pompeii",
    "Port Of Call",
    "Portsmouth",
    "Power Plant",
    "Prague",
    "Prep School",
    "Prescott Arizona",
    "Princeton University",
    "Prison Cell",
    "Promenade Deck",
    "Proving Ground",
    "Prussia",
    "Public Library",
    "Puerto Rico",
    "Purdue University",
    "Quantico Virginia",
    "Quebec City",
    "Queensland Australia",
    "Quincy Illinois",
    "Racetrack",
    "Redmond Washington",
    "Reform School",
    "Residence",
    "Restroom",
    "Rhodes Greece",
    "Rimini Italy",
    "Rochester New York",
    "Rock Garden",
    "Rockland County New York",
    "Rome's Tiber River",
    "Rooming House",
    "Root Cellar",
    "Rutgers University",
    "Rutland Vermont",
    "Safe Haven",
    "Saint Petersburg Florida",
    "Salad Bar",
    "Saloon",
    "San Francisco",
    "San Francisco's Haight-Ashbury",
    "Sand Trap",
    "Santa Barbara California",
    "Sarasota Florida",
    "Saratoga New York",
    "Savannah Georgia",
    "Scandinavia",
    "Scarsdale New York",
    "Scene Of The Crime",
    "School House",
    "Schoolroom",
    "Seaport",
    "Seat Of Government",
    "Seattle Washington",
    "Selma Alabama",
    "Seneca Falls New York",
    "Senior High School",
    "Service Station",
    "Seville Spain",
    "Shiloh Tennessee",
    "Shoe Repair Shop",
    "Siena Italy",
    "Singapore",
    "Ski Resort",
    "Snake Pit",
    "Solomon Islands",
    "Sonoma County California",
    "Sonora Mexico",
    "Soup Kitchen",
    "South Dakota's Badlands",
    "South Korea",
    "Southampton New York",
    "Sparta Greece",
    "St. Petersburg Russia",
    "St. Thomas",
    "St. Croix",
    "Stable",
    "Stadium",
    "Stairwell",
    "Staten Island",
    "Stateroom",
    "Steamboat Springs Colorado",
    "Stockton California",
    "Store",
    "Street Corner",
    "Stronghold",
    "Study Hall",
    "Subdivision",
    "Sudan",
    "Suez Canal",
    "Sumatra Indonesia",
    "Summer School",
    "Summer Camp",
    "Sunnyvale California",
    "Switzerland",
    "Sydney Australia",
    "Tahiti",
    "Tallahassee Florida",
    "Tampa Florida",
    "Taos New Mexico",
    "Tarrytown New York",
    "Tavern",
    "Tempe Arizona",
    "Terrace",
    "The Adirondacks",
    "The African Nation Of Chad",
    "The Allegheny Mountains",
    "The Atlantic Ocean",
    "The Australian Outback",
    "The Canadian Province Of Alberta",
    "The Catskill Mountains",
    "The Country Of Laos",
    "The Cumberland Gap",
    "The District Of Columbia",
    "The French Riviera",
    "The Garden Of Eden",
    "The Himalayas",
    "The Island Of Malta",
    "The Italian Riviera",
    "The Library Of Congress",
    "The Midwest",
    "The Mississippi Delta",
    "The Netherlands",
    "The Planet Mars",
    "The Planet Neptune",
    "The Planet Saturn",
    "The Planet Jupiter",
    "The Planet Uranus",
    "The Poconos",
    "The Potomac River",
    "The Rhine River",
    "The River Nile",
    "The Rockies",
    "The Sahara Desert",
    "The Tigris River",
    "The Wabash River",
    "The West Indies",
    "The Yucatan Peninsula",
    "The Yukon",
    "The Alps",
    "The Andes Mountains",
    "The Bronx",
    "The Czech Republic",
    "The French Quarter In New Orleans",
    "The Island Of Bali",
    "The Island Of Guam",
    "The Isle Of Wight",
    "The Lost Continent Of Atlantis",
    "The Mason-Dixon Line",
    "The North Pole",
    "The North Pole",
    "The Orange Bowl In Miami",
    "The Ozarks",
    "The Rim Of The Grand Canyon",
    "The Rose Bowl In Pasadena",
    "The Sea Of Galilee",
    "The Set Of A Movie",
    "The South American Country Of Peru",
    "Toledo Ohio",
    "Topeka Kansas",
    "Toronto Ontario Canada",
    "Tourist Trap",
    "Town",
    "Town Hall",
    "Townhouse",
    "Train Station",
    "Tropic Of Cancer",
    "Tropic Of Capricorn",
    "Tucson Arizona",
    "Tulane University",
    "Tunisia",
    "Tuscaloosa Alabama",
    "Tuscany",
    "Uganda",
    "Ukraine",
    "United States Naval Academy",
    "United States Of America",
    "Used Car Lot",
    "Utah's Bonneville Salt Flats",
    "Utica New York",
    "Vail Colorado",
    "Valhalla",
    "Valley Forge",
    "Vancouver British Columbia",
    "Vassar College",
    "Vicksburg Mississippi",
    "Vietnam",
    "Volcano's Crater",
    "Walden Pond",
    "Warehouse",
    "Waterbury Connecticut",
    "West Point",
    "Windsor Ontario",
    "Winner's Circle",
    "Workroom",
    "Yakima Washington",
    "Yale University",
    "Yokohama Japan",
    "Yonkers New York",
    "Yorktown Virginia",
    "Youngstown Ohio",
    "Yuma Arizona",
    "Zermatt Switzerland",
    "Zimbabwe"
],
"Landmark": [
    "Acadia National Park",
    "Bermuda's Pink Sand Beaches",
    "Big Bend National Park",
    "Boston Common",
    "Bryce Canyon National Park",
    "Buckingham Palace",
    "Death Valley National Monument",
    "Edison's Home In Menlo Park New Jersey",
    "Ellis Island",
    "Fort Davis National Historic Site",
    "Fort Point National Historic Site",
    "Fort Smith National Historic Site",
    "Glacier National Park",
    "Grand Canyon National Park",
    "Hyde Park National Historic Site",
    "Independence Hall In Philadelphia",
    "India's Ganges River",
    "Jerusalem's Wailing Wall",
    "John Muir National Historic Site",
    "Kings Canyon National Park",
    "Lassen Volcanic National Park",
    "London Bridge",
    "London's Covent Garden",
    "London's Tower Bridge",
    "Mesa Verde National Park",
    "Mount Palomar Observatory",
    "Mount Rushmore",
    "Muir Woods National Monument",
    "Niagara Falls",
    "Panama Canal",
    "Petrified Forest National Park",
    "Piccadilly Circus",
    "Plymouth Rock",
    "Redwood National Park",
    "San Francisco's Fisherman's Wharf",
    "Scotland Yard",
    "Sequoia National Park",
    "Serengeti National Park",
    "Signal Hill National Historic Site",
    "South Carolina's Fort Sumter",
    "Stonehenge",
    "The Eiffel Tower",
    "The Jefferson Memorial",
    "The Lincoln Memorial",
    "The Palace Of Versailles",
    "The Parthenon",
    "The Smithsonian Institution",
    "The Waldorf-Astoria Hotel",
    "The Washington Monument",
    "The White House",
    "The Alamo",
    "The Boston Post Road",
    "The Egyptian Pyramids",
    "The Empire State Building",
    "The Gateway Arch In St. Louis",
    "The Golden Gate Bridge",
    "The Great Wall Of China",
    "The Kremlin In Moscow",
    "The Mission Of San Juan Capistrano",
    "The Rock Of Gibraltar",
    "The Sphinx",
    "The Tower Of London",
    "Thomas Jefferson's Monticello",
    "Tokyo's Ginza District",
    "Valley Forge National Historical Park",
    "Walden Pond",
    "Westminster Abbey",
    "Winchester Cathedral",
    "Windsor Castle"
],
"Fictional Characters": [
    "Beavis & Butthead",
    "Big Bird Bert & Ernie",
    "Gumby & Pokey",
    "Hansel & Gretel",
    "Jonny Quest & Bandit",
    "Mermaids",
    "Mufasa Simba & Scar",
    "Ren & Stimpy",
    "Rocky & Bullwinkle",
    "The Dynamic Duo",
    "The Hardy Boys",
    "The Simpsons",
    "Tom And Jerry"
],
"Family": [
    "Blythe Danner & Gwyneth Paltrow",
    "Bruce & Laura Dern",
    "Judy Garland & Liza Minelli",
    "Loretta Lynn & Crystal Gayle",
    "Michael & Olympia Dukakis",
    "Naomi Wynonna & Ashley Judd",
    "Tony & Jamie Lee Curtis",
    "Vanessa & Lynn Redgrave",
    "Warren Beatty & Shirley Maclaine",
    "William Stephen & Alec Baldwin"
],
"Thing": [
    "A Glass Of Chablis",
    "A Kind Word",
    "A Lump Of Coal In Your Stocking",
    "Abbreviation",
    "Accident",
    "Accomplishment",
    "Achievement Award",
    "Acorn",
    "Acupuncture",
    "Adhesive Tape",
    "Adventure Story",
    "Adversity",
    "Advertising Agency",
    "Afghan Hound",
    "After-Dinner Drink",
    "Afternoon Snack",
    "Airplane",
    "Alarm Clock",
    "Algebra Textbook",
    "Allergy Shot",
    "Amber",
    "Amendment",
    "An Even Tan",
    "An Hour",
    "Anatomy",
    "Ancient History",
    "Anteater",
    "Antibiotic",
    "Apology",
    "Apple",
    "Appointment",
    "Aquamarine",
    "Aquarium",
    "Arrow",
    "Arrowhead",
    "Atmosphere",
    "Avocado",
    "Award",
    "Baby Face",
    "Baby Talk",
    "Baby's Crib",
    "Backpack",
    "Backup Generator",
    "Badger",
    "Bald Eagle",
    "Ball-Point Pen",
    "Ballad",
    "Balloon",
    "Bamboo",
    "Banana",
    "Banana Peel",
    "Barrage Of Questions",
    "Baseball Bat",
    "Baseball Cap",
    "Basket",
    "Basset Hound",
    "Bathroom Scale",
    "Bathtub",
    "Baton",
    "Battery",
    "Bay Window",
    "Beacon",
    "Beagle",
    "Bedspread",
    "Biography",
    "Birch Tree",
    "Birthmark",
    "Birthright",
    "Black Belt In Karate",
    "Black Bear",
    "Black Hole In Outer Space",
    "Blackberry",
    "Blackbird",
    "Blender",
    "Blood Type",
    "Bloodhound",
    "Blossom",
    "Blue Chip Stock",
    "Blueprint",
    "Board Game",
    "Book Review",
    "Boot Polish",
    "Bottomless Pit",
    "Box Score",
    "Boxcar",
    "Bracelet",
    "Braille",
    "Bread Machine",
    "Briefcase",
    "Brontosaurus",
    "Brush Stroke",
    "Bubble Bath",
    "Bulldog",
    "Bullet",
    "Bushel Basket",
    "Butter Churn",
    "Button",
    "Buttonhole",
    "Calculator",
    "Calendar",
    "Can Opener",
    "Can Of Soda",
    "Canceled Stamp",
    "Candlestick",
    "Candy Cane",
    "Canoe Paddle",
    "Canteen",
    "Cappuccino Maker",
    "Care Package",
    "Carrot Cake",
    "Catalog",
    "Catamaran",
    "Catapult",
    "Category",
    "Cathedral",
    "Cauliflower",
    "Cedar",
    "Ceiling Fan",
    "Cellular Phone",
    "Centimeter",
    "Chalk",
    "Cheese",
    "Cheetah",
    "Chemical Formula",
    "Chessboard",
    "Chicken",
    "Chicken Fried Steak",
    "Chimpanzee",
    "Chipmunk",
    "Chord",
    "Chorus",
    "Christmas Bonus",
    "Church Bell",
    "Clam Chowder",
    "Cleanser",
    "Closet Space",
    "Cloverleaf",
    "Coat And Tie",
    "Cocker Spaniel",
    "Coffee Cake",
    "Coincidence",
    "Coincidence",
    "College Scholarship",
    "Community",
    "Companionship",
    "Computer",
    "Confidence",
    "Conifer Tree",
    "Constellation",
    "Contemporary Jazz",
    "Controversy",
    "Cookie Cutter",
    "Corkscrew",
    "Corn Bread",
    "Cornucopia",
    "Cottage",
    "Counter",
    "Court Case",
    "Cover Charge",
    "Cranberry",
    "Crane",
    "Cypress Tree",
    "Dachshund",
    "Dalmatian",
    "Dear John Letter",
    "Dial Tone",
    "Dictionary Definition",
    "Dijon Mustard",
    "Dinosaur",
    "Diplomatic Immunity",
    "Dirty Trick",
    "Doberman Pinscher",
    "Dolphin",
    "Doorstep",
    "Doorstop",
    "Dot Matrix Printer",
    "Double Negative",
    "Double-Decker Bus",
    "Douglas Fir",
    "Dow Jones Industrial Average",
    "Dragon",
    "Dripping Faucet",
    "Drive-In Movie",
    "Duet",
    "Duffel Bag",
    "Dump Truck",
    "Dutch Elm Disease",
    "Earthworm",
    "Easter Lily",
    "Eggplant Parmigiana",
    "Einstein's Theory Of Relativity",
    "Electric Blanket",
    "Electricity",
    "Element",
    "Elephant",
    "Elm Tree",
    "Empty Nest",
    "End Table",
    "English Translation",
    "Entertainment",
    "Envelope",
    "Escape Hatch",
    "Estimate",
    "Etching",
    "Evergreen Tree",
    "Evidence",
    "Expense Account",
    "Express Lane",
    "Extension Cord",
    "Extension Ladder",
    "Extra-Large Size",
    "Falcon",
    "False Alarm",
    "Family Heirloom",
    "Family Name",
    "Felt Tip Pen",
    "Filter",
    "Final Adjustment",
    "Finch",
    "Finger Food",
    "Finger Paint",
    "Fingernail",
    "Finish Line",
    "Fire Hose",
    "Fire Insurance",
    "Fireplace",
    "Firewood",
    "First Day Of The Month",
    "First-Class Mail",
    "Five-Digit Zip Code",
    "Flashlight",
    "Flat Tire",
    "Flavor Of The Month",
    "Flood Insurance",
    "Floor Plan",
    "Floppy Disk",
    "Flower Arrangement",
    "Flu Vaccination",
    "Flu Shot",
    "Fluorescent Light",
    "Flying Fish",
    "Food Processor",
    "Footrest",
    "Form Letter",
    "Fountain Of Youth",
    "Fountain Pen",
    "Fox Terrier",
    "Free Enterprise",
    "Free Offer",
    "French Bread",
    "French Horn",
    "French Poodle",
    "Frisbee",
    "Fruit Punch",
    "Funnel",
    "Gall Bladder",
    "Gallon",
    "Gander",
    "Garden Hose",
    "Gardenia",
    "General Assessment",
    "Geometry",
    "Get-Rich-Quick Scheme",
    "Giggle",
    "Gingerbread",
    "Goat Cheese",
    "Golden Retriever",
    "Good Advice",
    "Good Penmanship",
    "Grab Bag",
    "Grape",
    "Graph Paper",
    "Gravel",
    "Grease Paint",
    "Great White Shark",
    "Great Dane",
    "Greek Food",
    "Green Grass",
    "Greyhound",
    "Grizzly Bear",
    "Ground Beef",
    "Groundhog",
    "Group Rate",
    "Growth Rate",
    "Guide Dog",
    "Guilty Conscience",
    "Gutter",
    "Haircut",
    "Hairstyle",
    "Half An Hour",
    "Ham And Cheese Sandwich",
    "Handbook",
    "Handlebar Mustache",
    "Handwriting",
    "Happiness",
    "Help Wanted Ad",
    "Hemlock",
    "Hickory",
    "High Fever",
    "High School Diploma",
    "High-Fiber Cereal",
    "High-Five",
    "Higher Education",
    "Hippopotamus",
    "Hiring Freeze",
    "Holy Roman Empire",
    "Homesickness",
    "Homework Assignment",
    "Honeybee",
    "Hook Shot",
    "Hoot Owl",
    "Horizon",
    "Hornet's Nest",
    "Horoscope",
    "Horseradish",
    "Hot Compress",
    "Hot Sauce",
    "Hourglass",
    "Houseboat",
    "Huckleberry",
    "Human Nature",
    "Humility",
    "Ice Pick",
    "Income Tax",
    "Indelible Ink",
    "Initiative",
    "Inner Tube",
    "Invisible Ink",
    "Irish Setter",
    "Jade Pendant",
    "Jaguar",
    "Javelin",
    "Jawbone",
    "Jazz Music",
    "Jelly Doughnut",
    "Journal",
    "Journalism",
    "Keepsake",
    "Kentucky Bluegrass",
    "Keynote Address",
    "Kickstand",
    "Kid Gloves",
    "Kilogram",
    "Knee Jerk Reaction",
    "Knockout Blow",
    "Knot",
    "Knotty Pine",
    "Laptop Computer",
    "Lasagna",
    "Laser Printer",
    "Lasso",
    "Laughter",
    "Laundry Cart",
    "Lawn Mower",
    "Leaf Blower",
    "Learner's Permit",
    "Leopard",
    "Lettuce",
    "Lhasa Apso",
    "Liar's Poker",
    "Life Preserver",
    "Lifeboat",
    "Light",
    "Lighthouse",
    "Lightning",
    "Limestone",
    "Liter",
    "Lithograph",
    "Litmus Test",
    "Little Black Book",
    "Lobster",
    "Lock Of Hair",
    "Loophole",
    "Loudspeaker",
    "Lovebird",
    "Low-Cholesterol Diet",
    "Low-Fat Diet",
    "Macaw",
    "Magic Carpet",
    "Magic Marker",
    "Mallard",
    "Mandarin Orange",
    "Mango",
    "Mangrove",
    "Mannequin",
    "Map Of The World",
    "Maple Tree",
    "Marmalade",
    "Marriage",
    "Marshmallow",
    "Masterpiece",
    "Matchbook",
    "Maternal Instinct",
    "Meadow",
    "Melody",
    "Melon",
    "Melted Cheese",
    "Memoir",
    "Memorandum",
    "Memory",
    "Metaphor",
    "Meter",
    "Mexican Sombrero",
    "Microphone",
    "Microscope",
    "Microwave Oven",
    "Mint Julep",
    "Minus Sign",
    "Minute",
    "Mixed Blessing",
    "Mobile Phone",
    "Monday Morning Traffic",
    "Monkey",
    "Monument",
    "Morning Glory",
    "Motorcycle",
    "Mountain Bike",
    "Mountain Goat",
    "Mountain Lion",
    "Mountain Range",
    "Multiple-Choice Question",
    "Mushroom",
    "Mustard",
    "Mutual Understanding",
    "Navy Blue Suit",
    "Necklace",
    "Negative Feedback",
    "Neon Sign",
    "Net Profit",
    "Newspaper",
    "Night Table",
    "Nightgown",
    "Nightingale",
    "Noisemaker",
    "Nonstop Flight",
    "Nourishment",
    "Nuclear Physics",
    "Nuclear Power Plant",
    "Oak Tree",
    "Oatmeal",
    "Obligation",
    "Octopus",
    "Oil Well",
    "Old English Sheepdog",
    "Olive Oil",
    "Opera",
    "Opinion",
    "Orange",
    "Orange Blossom",
    "Orange Tree",
    "Ornament",
    "Ounce",
    "Over-The-Counter Medication",
    "Pair Of Pants",
    "Palm Tree",
    "Pamphlet",
    "Panda",
    "Pane Of Glass",
    "Papaya",
    "Paragraph",
    "Park Bench",
    "Parking Meter",
    "Parrot",
    "Pause",
    "Pay-Per-View Television",
    "Peace Offering",
    "Peach",
    "Peach Cobbler",
    "Pear Tree",
    "Peat Moss",
    "Pecan",
    "Peck Of Pickled Peppers",
    "Pedestal",
    "Peer Pressure",
    "Penguin",
    "Percolator",
    "Perfect Pitch",
    "Periscope",
    "Phone Call",
    "Piece Of Pie",
    "Pigeon",
    "Pillow",
    "Pilot Light",
    "Pine Tree",
    "Pint Of Milk",
    "Pipe Dream",
    "Plastic Surgery",
    "Pocket",
    "Pocket Comb",
    "Poetic Justice",
    "Poetic License",
    "Polar Ice Cap",
    "Pollution",
    "Popcorn",
    "Pork Chop",
    "Porpoise",
    "Porterhouse Steak",
    "Porthole",
    "Postponement",
    "Pound",
    "Prayer Book",
    "Press Pass",
    "Pressure Cooker",
    "Prime Time Television",
    "Printing Press",
    "Prompt Response",
    "Proper Noun",
    "Prosperity",
    "Public Address System",
    "Pulitzer Prize",
    "Pulley",
    "Pup Tent",
    "Puppet Show",
    "Purchase Order",
    "Putting Green",
    "Pyramid",
    "Python",
    "Quantum Physics",
    "Quart",
    "Quartz Watch",
    "Rabbit",
    "Racehorse",
    "Radio Broadcast",
    "Railroad",
    "Rainbow",
    "Rap Music",
    "Raspberry",
    "Ratings System",
    "Rattlesnake",
    "Raven",
    "Ream Of Paper",
    "Receding Hairline",
    "Recipe",
    "Recliner",
    "Record Album",
    "Rectangle",
    "Red Herring",
    "Refrigerator",
    "Relationship",
    "Remedy",
    "Reminder",
    "Rent Payment",
    "Retirement Age",
    "Rhinoceros",
    "Rhythm",
    "Rice Paper",
    "Ripple In The Water",
    "Road Map",
    "Roadblock",
    "Robot",
    "Rock Cornish Game Hen",
    "Rocking Chair",
    "Rocky Road Ice Cream",
    "Rolling Pin",
    "Room Service",
    "Rooster",
    "Rose Bush",
    "Rosebud",
    "Rubber",
    "Rubber Band",
    "Rubber Stamp",
    "Rush Hour Traffic",
    "Rust Remover",
    "Rye Bread",
    "Sacrifice Fly",
    "Saddle",
    "Safety Net",
    "Saffron",
    "Sagebrush",
    "Saint Bernard Dog",
    "Salad Dressing",
    "Salary",
    "Saltwater Fish",
    "Sand Bag",
    "Sand Dollar",
    "Sandpaper",
    "Sandstone",
    "Sandwich",
    "Sapphire",
    "Satin",
    "Sausage",
    "Savings And Loan Association",
    "Savings Bond",
    "Schnauzer",
    "Scholarship",
    "School Play",
    "School Year",
    "Score Card",
    "Scotch Tape",
    "Screen Saver",
    "Screen Test",
    "Sea Urchin",
    "Sea Horse",
    "Sea Lion",
    "Seafood",
    "Seagull",
    "Search Warrant",
    "Searchlight",
    "Secret Identity",
    "Seeing Eye Dog",
    "Self-Control",
    "Self-Esteem",
    "Self-Portrait",
    "Semi-Circle",
    "Semicolon",
    "Sense Of Smell",
    "Sentence",
    "Septic Tank",
    "Sequoia",
    "Service Elevator",
    "Sewing Machine",
    "Shadow",
    "Shag Carpet",
    "Shark Fin",
    "Sheet Music",
    "Shellfish",
    "Shipment",
    "Shoehorn",
    "Shooting Star",
    "Shopping Cart",
    "Short Story",
    "Shorthand",
    "Shoulder",
    "Shovel",
    "Show Business",
    "Shower",
    "Shrink-Wrap",
    "Side Street",
    "Sign Language",
    "Silence",
    "Silkworm",
    "Silver Platter",
    "Skeleton",
    "Ski Lift",
    "Skim Milk",
    "Skylight",
    "Sleeping Bag",
    "Slingshot",
    "Slow Dance",
    "Smoke Screen",
    "Snapdragon",
    "Snapshot",
    "Snowball",
    "Snowdrift",
    "Soapbox",
    "Social Security Check",
    "Soda Fountain",
    "Soda Water",
    "Sofa Bed",
    "Software",
    "Solar System",
    "Song And Dance Routine",
    "Sonic Boom",
    "Sore Throat",
    "Soup Ladle",
    "Southbound Train",
    "Souvenir",
    "Space Heater",
    "Spaghetti Sauce",
    "Spare Change",
    "Spark Plug",
    "Sparkling Mineral Water",
    "Sparrow",
    "Spearmint Gum",
    "Special Assignment",
    "Specimen",
    "Spectacle",
    "Speedboat",
    "Spell-Checker",
    "Spider Monkey",
    "Spinal Column",
    "Spine-Tingling Adventure",
    "Spinning Wheel",
    "Splinter",
    "Split Decision",
    "Split-Level House",
    "Spruce",
    "Stack Of Paper",
    "Stallion",
    "Stamp",
    "Starfish",
    "Starry Night",
    "Status Report",
    "Steam Engine",
    "Steel Wool",
    "Steep Hill",
    "Stegosaurus",
    "Stencil",
    "Step Stool",
    "Stepstool",
    "Sterling Silver",
    "Stick",
    "Stiff Neck",
    "Stingray",
    "Stop Sign",
    "Stove",
    "Stovepipe Hat",
    "Strand Of Hair",
    "Strawberry Jam",
    "Stretcher",
    "String Bean",
    "Striped Bass",
    "Stumbling Block",
    "Submarine",
    "Sunny Afternoon",
    "Sunshine",
    "Sunstroke",
    "Survey",
    "Sweat Suit",
    "Sweater",
    "Swimming Pool",
    "Swiss Bank Account",
    "Swordfish",
    "Sycamore Tree",
    "Tabasco Sauce",
    "Table Tennis",
    "Tablecloth",
    "Tablespoon",
    "Tail Pipe",
    "Taillight",
    "Talk Show",
    "Tank Top",
    "Tea Service",
    "Technology",
    "Telephone",
    "Telescope",
    "Television Remote Control",
    "Temperature",
    "Test Tube",
    "Thank-You Note",
    "The Bronze Age",
    "The Milky Way",
    "The Mother Lode",
    "The Polka",
    "The Scales Of Justice",
    "The Stone Age",
    "The Fifth Amendment",
    "The First Commandment",
    "The Moon",
    "The Old Testament",
    "Theater In The Round",
    "Thimble",
    "Third-Class Mail",
    "Thirst",
    "Thousand Island Dressing",
    "Throat",
    "Throw Rug",
    "Thunderbolt",
    "Ticket",
    "Timber Wolf",
    "Title Page",
    "Toaster Oven",
    "Tollbooth",
    "Tomato",
    "Toothbrush",
    "Tortoise",
    "Toss-Up Question",
    "Tote Bag",
    "Tour Of Duty",
    "Toy Chest",
    "Trade Agreement",
    "Trademark",
    "Tradition",
    "Transcript",
    "Trap Door",
    "Trapeze",
    "Trash Can",
    "Traveler's Check",
    "Treasure Trove",
    "Triceratops",
    "Trilogy",
    "Tripod",
    "Tulip",
    "Turnstile",
    "Tweed Suit",
    "Twenty-Twenty Vision",
    "Two-By-Four",
    "Typing Paper",
    "Tyrannosaurus Rex",
    "Underpass",
    "Vacuum Cleaner",
    "Violet",
    "VIP Treatment",
    "Vocabulary",
    "Volleyball",
    "Volume Control",
    "Vote Of Confidence",
    "Vow Of Silence",
    "Vulture",
    "Wading Pool",
    "Waffle Iron",
    "Wagon Train",
    "Waistline",
    "Walnut",
    "Walnut",
    "Walrus",
    "Wardrobe",
    "Warp Speed",
    "Watch",
    "Water",
    "Water Balloon",
    "Water Cooler",
    "Water Pump",
    "Waterfall",
    "Waterfowl",
    "Wedding Cake",
    "Weekly Paycheck",
    "Weeping Willow Tree",
    "Wheat Germ",
    "Whiplash",
    "Wide-Angle Lens",
    "Wild Rice",
    "Will Power",
    "Willow",
    "Window Shade",
    "Winter Squash",
    "Wisdom",
    "Wisdom Tooth",
    "Woodpile",
    "Worcestershire Sauce",
    "World Atlas",
    "Wristband",
    "Wristwatch",
    "Writer's Cramp",
    "Yellow-Bellied Sapsucker"
],
"People": [
    "A Foursome For Golf",
    "Abbott And Costello",
    "Absentee Voters",
    "Ace Of Base",
    "Actors",
    "Amish Farmers",
    "Atlanta Falcons",
    "Australians",
    "Baby Boomers",
    "Baritone Bass & Tenor",
    "Beat Poets",
    "Bebe & Cece Winans",
    "Blood Relatives",
    "Boy Scout Troop",
    "Britain's Labor Party",
    "Cast Members",
    "Celebrity Panel",
    "Celts Picts & Saxons",
    "Chicago Bears",
    "Children",
    "Choir",
    "Coast Guard",
    "Committee Members",
    "Comparison Shoppers",
    "Cops And Robbers",
    "Counting Crows",
    "Crash Test Dummies",
    "Critics",
    "Cypress Hill",
    "Daughters Of The American Revolution",
    "Democrats",
    "Denver Broncos",
    "Distinguished Colleagues",
    "English Majors",
    "Explorers",
    "Family Members",
    "Farm Team",
    "Fast Friends",
    "Father And Son",
    "Firing Squad",
    "Forefathers",
    "Future Generations",
    "Game Show Audience",
    "Glee Club",
    "Grammy Award Winners",
    "Green Day",
    "Grown-Ups",
    "Gypsies",
    "Historical Figures",
    "Hootie And The Blowfish",
    "Husband And Wife",
    "Immigrants",
    "Impostors",
    "Indigo Girls",
    "Infants",
    "Inhabitants",
    "Instructors",
    "Journalists",
    "Jugglers",
    "Justices Of The Supreme Court",
    "Kansas City Chiefs",
    "Kindergarten Students",
    "Kings And Queens",
    "Lads And Lasses",
    "Legislators",
    "Liberals",
    "Lords And Ladies",
    "Los Angeles Raiders",
    "Loyal Customers",
    "Magazine Subscribers",
    "Men Women And Children",
    "Middle-Class Family",
    "Minor League Players",
    "Mohawk Indians",
    "Mother And Daughter",
    "Neighbors",
    "New Orleans Saints",
    "New York Jets",
    "Nine Inch Nails",
    "Nirvana",
    "Old Friends",
    "Opera Singers",
    "Parent-Teacher Association",
    "Parents",
    "Partners In Crime",
    "Pearl Jam",
    "Pen Pals",
    "Physicians",
    "Pink Floyd",
    "Playmates",
    "Police Officers",
    "Private Investigators",
    "Producer And Director",
    "Proprietors",
    "Republicans",
    "Role Models",
    "Roman Emperors",
    "Roommates",
    "Salt-N-Pepa",
    "San Francisco Forty-Niners",
    "San Diego Chargers",
    "Search Party",
    "Senior Citizens",
    "Seventh Grade Teachers",
    "Simply Red",
    "Sisters",
    "Small Children",
    "Smashing Pumpkins",
    "Snake Charmers",
    "Soundgarden",
    "Sponsors",
    "Squadron",
    "State Legislature",
    "Sumo Wrestlers",
    "Sunday School Teachers",
    "Switch Hitters",
    "Symphony Orchestra",
    "Talking Heads",
    "Team Members",
    "Teenagers",
    "Texans",
    "The Confederate Army",
    "The Cranberries",
    "The Czars Of Russia",
    "The Doors",
    "The Dream Team",
    "The League Of Nations",
    "The Mighty Ducks",
    "The Monkees",
    "The Peace Corps",
    "The Sheriff & His Posse",
    "The Brat Pack",
    "The Green Berets",
    "The House Ways And Means Committee",
    "The Mighty Ducks",
    "The People Next Door",
    "The Tudor Kings Of England",
    "Toad The Wet Sprocket",
    "Tony Orlando And Dawn",
    "Trade Union",
    "Twins",
    "U.S. Navy Seals",
    "Vikings",
    "Winners And Losers"
],
"Phrase": [
    "A Momentary Lapse",
    "A Reflection Of Our Times",
    "A Cursory Glance",
    "A Dead Ringer",
    "A Far Far Better Thing",
    "A Figment Of Your Imagination",
    "A Fox In The Henhouse",
    "A Fresh Point Of View",
    "A Friend In Need Is A Friend Indeed",
    "A Gleam In Your Eye",
    "A Gutsy Move",
    "A Land-Office Business",
    "A Matter Of Policy",
    "A Meal In Itself",
    "A Moot Point",
    "A Novel Idea",
    "A Penny For Your Thoughts",
    "A Plan Of Action",
    "A Rolling Stone Gathers No Moss",
    "A Run For Your Money",
    "A Slight Chance Of Showers",
    "A Stab In The Back",
    "A Stitch In Time Saves Nine",
    "A Straw In The Wind",
    "A Sure Thing",
    "A Total Loss",
    "Alive And Kicking",
    "All Along The Line",
    "All That Glitters Is Not Gold",
    "All's Fair In Love And War",
    "An Apple A Day Keeps The Doctor Away",
    "An Exception To The Rule",
    "An Extra Pair Of Eyes",
    "An Uphill Battle",
    "And All That Jazz",
    "Animal Vegetable Or Mineral",
    "Are You Decent",
    "Are You Waiting For An Engraved Invitation",
    "Around The Bend",
    "As Pure As The Driven Snow",
    "As Rare As Hens' Teeth",
    "At Any Rate",
    "At The Helm",
    "At The Present Time",
    "At The Same Time",
    "Batteries Not Included",
    "Battling The Forces Of Evil",
    "Be Still",
    "Been Down So Long It Looks Like Up To Me",
    "Before The Parade Passes You By",
    "Beggars Can't Be Choosers",
    "Behave Yourself",
    "Behind The Scenes",
    "Behind The Eight-Ball",
    "Behind The Wheel",
    "Besieged With Requests",
    "Betwixt And Between",
    "Birds Of A Feather Flock Together",
    "Bite The Bullet",
    "Blood Is Thicker Than Water",
    "Brace Yourself",
    "Breath-Taking Beauty",
    "Bring Them Into The Fold",
    "Busy As A Bee",
    "Buying On Margin",
    "By The Nape Of The Neck",
    "Call A Cab",
    "Can A Leopard Change Its Spots",
    "Can I Quote You On That",
    "Cash And Carry",
    "Cash On The Barrelhead",
    "Cast Aspersions",
    "Catch-As-Catch-Can",
    "Caught Short-Handed",
    "Cease And Desist",
    "Change Your Tune",
    "Charity Begins At Home",
    "Check Please",
    "Check Your Sources",
    "Chewing Its Cud",
    "Class Dismissed",
    "Clean Your Room",
    "Clip Coupons",
    "Close Quarters",
    "Closed Until Further Notice",
    "Cross Your Palm With Silver",
    "Cry Yourself To Sleep",
    "Curiosity Killed The Cat",
    "Current Whereabouts Unknown",
    "Cut And Dried",
    "Cut And Paste",
    "Cute As A Button",
    "Dim The Lights",
    "Dinner Is In The Oven",
    "Do Your Duty",
    "Don't Look Back",
    "Don't Make Waves",
    "Don't Talk Back",
    "Don't Be So Naive",
    "Don't Be Such A Pest",
    "Don't Get Nasty With Me",
    "Don't Give Me Any Lip",
    "Don't Just Stand There",
    "Don't Let It Slip Away",
    "Don't Lie Down On The Job",
    "Don't Put All Your Eggs In One Basket",
    "Don't Stand On Ceremony",
    "Don't Take It Lying Down",
    "Double Your Pleasure",
    "Down The Drain",
    "Down Under",
    "Duck For Cover",
    "Earn Your Keep",
    "Easier Said Than Done",
    "East Is East And West Is West",
    "End Of The Line",
    "End Of The Road",
    "Enjoy It While You Can",
    "Enough Is Enough",
    "Every Cloud Has A Silver Lining",
    "Every Tom Dick And Harry",
    "Face To Face",
    "Facing The Future",
    "Fade Away",
    "Fair To Middling",
    "Faith And Trust",
    "Fame And Fortune",
    "Familiarity Breeds Contempt",
    "Famous Last Words",
    "Feed A Cold And Starve A Fever",
    "Feel The Heat",
    "Fifteen Minutes Of Fame",
    "Fighting Tooth And Nail",
    "Fill Me In On It",
    "Find Favor With",
    "Finders Keepers",
    "Fleet Of Foot",
    "Fluent In Five Languages",
    "Fly By Night",
    "Flying Blind",
    "Foiled At Every Turn",
    "Follow The Leader",
    "Follow The Herd",
    "Fool's Errand",
    "Foot The Bill",
    "Footloose And Fancy Free",
    "For Heaven's Sake",
    "For Pity's Sake",
    "For All Intents And Purposes",
    "For All The World To See",
    "For Better For Worse",
    "For Keeps",
    "For Richer For Poorer",
    "For The Love Of Mike",
    "For Your Information",
    "Fork It Over",
    "From Another Planet",
    "From Coast To Coast",
    "From Stem To Stern",
    "From This Day Forward",
    "Funny Money",
    "Game Set And Match",
    "Get A Grip On Yourself",
    "Get A Leg Up",
    "Get A Fix On It",
    "Get In Just Under The Wire",
    "Getting A Fair Shake",
    "Getting The Cold Shoulder",
    "Giant Size",
    "Give Him Enough Rope To Hang Himself",
    "Give Him His Walking Papers",
    "Give It The Old College Try",
    "Give It Your Best Effort",
    "Give Me A Sign",
    "Give Your Notice",
    "Glad To Meet You",
    "Go Ahead Sue Me",
    "Go Figure",
    "Go For Broke",
    "Go Out Of Your Way",
    "Going Full Throttle",
    "Going Going Gone",
    "Going Great Guns",
    "Going To Town",
    "Going By The Script",
    "Gone Fishin'",
    "Gone To Seed",
    "Good Grief",
    "Good For Nothing",
    "Graduate With Honors",
    "Great Day In The Morning",
    "Grow Up",
    "Guess Again",
    "Guilty As Charged",
    "Halt Who Goes There",
    "Hand Over Fist",
    "Hands Up",
    "Hang Around",
    "Hang On",
    "Hardly A Day Goes By",
    "Haste Makes Waste",
    "Have A Nice Day",
    "Haven't Seen Hide Nor Hair Of Him",
    "Having A Ball",
    "He Got A Raw Deal",
    "He Speaks Very Highly Of You",
    "He Who Hesitates Is Lost",
    "He's Got A Few Loose Screws",
    "Heaven And Earth",
    "Heaven Only Knows",
    "Heavens Above",
    "Here And Now",
    "High And Dry",
    "Highs And Lows",
    "His And Hers",
    "Hit The Jackpot",
    "Hold On Tight",
    "Holding Up Your End Of The Bargain",
    "Home Sweet Home",
    "How Much Do You Need",
    "Hurry Home",
    "I Beg Your Pardon",
    "I Can Manage Just Fine",
    "I Can't Recall",
    "I Demand My Rights",
    "I Don't Mind If I Do",
    "I Don't Want To Burst Your Bubble",
    "I Gave At The Office",
    "I Gave It Up For Lent",
    "I Hate To Eat And Run",
    "I Have No Use For It",
    "I Have Nothing More To Say",
    "I Have It All At My Fingertips",
    "I Haven't Got A Clue",
    "I Hear You Loud And Clear",
    "I Knew It All Along",
    "I Know What I Saw",
    "I Like It Like That",
    "I Mean What I Say",
    "I Regret To Inform You",
    "I Second The Motion",
    "I Spoke Too Soon",
    "I Tip My Hat To You",
    "I Want To Be Alone",
    "I Wash My Hands Of It",
    "I'll Be With You In A Minute",
    "I'll Run A Tab",
    "I'll Take You At Your Word",
    "I'm Looking Forward To It",
    "I'm Fond Of You",
    "I'm In Seventh Heaven",
    "I'm Not Buying It",
    "I'm Out Of Here",
    "I'm Stuck On You",
    "I'm Trying To Get The Kinks Out",
    "I've Formed An Opinion",
    "I've Got My Money On You",
    "If Looks Could Kill",
    "In Broad Daylight",
    "In Fits And Starts",
    "In Hot Water",
    "In My Neck Of The Woods",
    "In One Ear And Out The Other",
    "In The Face Of Danger",
    "In The Flesh",
    "In The Line Of Duty",
    "In The Nick Of Time",
    "In The Prime Of Life",
    "In Your Neck Of The Woods",
    "In Your Stocking Feet",
    "It Couldn't Happen To A Nicer Guy",
    "It Didn't Pan Out",
    "It Didn't Ring True",
    "It Never Fails",
    "It Seems Like Only Yesterday",
    "It Takes All Kinds",
    "It Takes Guts",
    "It Takes Two To Tango",
    "It Varies From Day To Day",
    "It Will Come To Pass",
    "It's A Crying Shame",
    "It's A Dog-Eat-Dog World",
    "It's A Living",
    "It's A Pity",
    "It's A Snap",
    "It's All The Rage",
    "It's High Time",
    "It's No Skin Off My Nose",
    "It's No Use Crying Over Spilt Milk",
    "It's Not All It's Cracked Up To Be",
    "It's Only Money",
    "It's Your Move",
    "Jumping To Conclusions",
    "Just Like Starting Over",
    "Just One Of The Guys",
    "Keep At It",
    "Keep It To Yourself",
    "Keep It Under Wraps",
    "Keep The Peace",
    "Keep Those Cards And Letters Coming",
    "Keep Time",
    "Keep Your Eyes Peeled",
    "Keep Your Fingers Crossed",
    "Keep Your Head",
    "Keep Your Losses To A Minimum",
    "Keeping Things On An Even Keel",
    "Keeping Up With The Joneses",
    "Knock On Wood",
    "Land On Your Feet",
    "Landed With A Thud",
    "Larger Than Life",
    "Last But Not Least",
    "Lean And Mean",
    "Less Is More",
    "Let It Ride",
    "Let The Buyer Beware",
    "Let Your Hair Down",
    "Let's Make Tracks",
    "Let's Play Fair",
    "Lie In State",
    "Like A Bull In A China Shop",
    "Like Father Like Son",
    "Like Taking Candy From A Baby",
    "Like Two Peas In A Pod",
    "Listen To Reason",
    "Living Proof",
    "Living Up To Expectations",
    "Living In The Lap Of Luxury",
    "Lo And Behold",
    "Loads Of Fun",
    "Look Before You Leap",
    "Looks Aren't Everything",
    "Lost And Found",
    "Made In America",
    "Make Yourself Scarce",
    "Make A Funny Face",
    "Make Me An Offer I Can't Resist",
    "Make Time",
    "Make Way",
    "Making A Big Splash",
    "Making Eye Contact",
    "Meeting On Neutral Ground",
    "Might Makes Right",
    "Mind Your Own Business",
    "Moving At A Snail's Pace",
    "My Suitcases Are Packed",
    "Neat As A Pin",
    "Never A Dull Moment",
    "Never Trust Anyone Over Thirty",
    "New And Improved",
    "News At Eleven",
    "Nice To See You",
    "No Offense Meant",
    "No Questions Asked",
    "No More Mr. Nice Guy",
    "No Place To Hide",
    "No Pun Intended",
    "No Room For Error",
    "No Takers",
    "Not At The Moment",
    "Not For All The Tea In China",
    "Not For Publication",
    "Not My Style",
    "Not On Your Life",
    "Not Worth A Hill Of Beans",
    "Nothing But Trouble",
    "Nothing But The Best",
    "Nothing In Common",
    "Nothing To Lose",
    "Now Hear This",
    "Nurse Your Wounds",
    "Odd Man Out",
    "Off Limits",
    "Off And Running",
    "Off To The Races",
    "Old Habits Die Hard",
    "On The Face Of It",
    "On The Launching Pad",
    "On The Level",
    "On The Make",
    "On The Right Track",
    "On The Straight And Narrow",
    "On The Tip Of My Tongue",
    "On The Verge Of Tears",
    "On The Move",
    "On The Run",
    "Once And For All",
    "Once In A Blue Moon",
    "One In A Million",
    "One Size Fits All",
    "Or So He Said",
    "Out Of Harm's Way",
    "Out Of Sync",
    "Out Of The Clear Blue Sky",
    "Out Of The Loop",
    "Out Of The Mouths Of Babes",
    "Out Of The Running",
    "Out Of Touch",
    "Out On My Own",
    "Over Hill And Dale",
    "Over The Edge",
    "Over The Top",
    "Over The Top",
    "Pacing Back And Forth",
    "Paid In Full",
    "Pamper Yourself",
    "Pancakes",
    "Paper Or Plastic",
    "Pay The Piper",
    "Pay Your Dues",
    "Pay Your Own Way",
    "People Will Talk",
    "Pick A Card Any Card",
    "Pick Up The Pace",
    "Pinching Pennies",
    "Pitch Black",
    "Places Everyone",
    "Places Everyone",
    "Playing By The Rules",
    "Please Wait Your Turn",
    "Poetic Justice",
    "Poetry In Motion",
    "Point Of No Return",
    "Power To The People",
    "Practice Makes Perfect",
    "Pretty As A Picture",
    "Pull Back On The Reins",
    "Pure Coincidence",
    "Pure As The Driven Snow",
    "Put Out The Fire",
    "Put Up A Good Fight",
    "Put Your Cards On The Table",
    "Putting Down Roots",
    "Quick As A Wink",
    "Quit While Yo're Ahead",
    "Ragged Around The Edges",
    "Rags To Riches Story",
    "Raining Cats And Dogs",
    "Ran Into A Little Snag",
    "Ranting And Raving",
    "Reaching The Outer Limits",
    "Recommended Dosage",
    "Related On My Mother's Side",
    "Remember When",
    "Ride Herd",
    "Riding Tall In The Saddle",
    "Right Of Way",
    "Ring Around The Rosie",
    "Rinky-Dink",
    "Roll The Dice",
    "Roll Up Your Sleeves",
    "Room For One More",
    "Rough Sailing Ahead",
    "Round Off To The Nearest Number",
    "Ruffled Feathers",
    "Run For Your Life",
    "Run Of The Mill",
    "Safe And Sound",
    "Sail Away",
    "Save Your Pennies For A Rainy Day",
    "Say Uncle",
    "Scared Stiff",
    "Season's Greetings",
    "Seize The Moment",
    "Selling Like Hotcakes",
    "Sent Him Packing",
    "Served On A Silver Platter",
    "Set Aside Some Time",
    "Set In His Ways",
    "Share And Share Alike",
    "Ship Ahoy",
    "Short-Changed",
    "Sight Unseen",
    "Sign Of The Times",
    "Signed Sealed And Delivered",
    "Sincerely Yours",
    "Sit Back And Relax",
    "Skating On Thin Ice",
    "Skin Deep",
    "Slim Pickings",
    "Slip Of The Tongue",
    "Smooth As Silk",
    "Snake Eyes",
    "Snuggle Up",
    "Sole Support",
    "Something To That Effect",
    "Soon Enough",
    "Sound The Wrong Note",
    "Spare The Rod And Spoil The Child",
    "Speak Of The Devil",
    "Spring Fever",
    "Stand Back And Watch The Fur Fly",
    "Stand Pat",
    "State Of The Art",
    "Stay On Your Toes",
    "Stay Tuned",
    "Steal Away",
    "Stem The Tide",
    "Stick It Out",
    "Stick Out Your Tongue",
    "Stir It Up",
    "Stop At Nothing",
    "Stop Making A Scene",
    "Store This End Up",
    "Stow Your Gear Here",
    "Street Smart",
    "Strictly Business",
    "Strike While The Iron Is Hot",
    "Strike A Pose",
    "Strike It Rich",
    "Supply And Demand",
    "Swan Song",
    "Sweep Under The Rug",
    "Sweet Dreams",
    "Swing Shift",
    "Take A Memo",
    "Take After Meals",
    "Take Detailed Notes",
    "Take Heart",
    "Take Your Pick",
    "Take A Back Seat",
    "Take A Load Off",
    "Take A Peek",
    "Take A Siesta",
    "Take It Easy",
    "Take It On The Chin",
    "Take It With A Grain Of Salt",
    "Taken By Storm",
    "Taking Advantage Of The Situation",
    "Taking Care Of Business",
    "Taking The Lion's Share",
    "Taking Turns",
    "Taking A Nap",
    "Talk A Blue Streak",
    "Talk It Over",
    "Thank Your Lucky Stars",
    "That Really Hits Home",
    "That Remains To Be Seen",
    "That Hits The Spot",
    "That Was Then This Is Now",
    "That'll Do The Trick",
    "That's Strong Medicine",
    "That's Tooting Your Own Horn",
    "That's All She Wrote",
    "That's All Well And Good",
    "That's Not The Worst Of It",
    "That's The Way Of The World",
    "The Bigger They Are The Harder They Fall",
    "The Calm Before The Storm",
    "The Check Is In The Mail",
    "The Crux Of The Matter",
    "The Day Before Yesterday",
    "The Early Bird Catches The Worm",
    "The Facts Of Life",
    "The Hustle And Bustle Of The Big City",
    "The Lay Of The Land",
    "The Letter Of The Law",
    "The Manner To Which You Are Accustomed",
    "The Milk Of Human Kindness",
    "The More The Merrier",
    "The Pen Is Mightier Than The Sword",
    "The Plot Thickens",
    "The Pot Calling The Kettle Black",
    "The Proof Is In The Pudding",
    "The Sky's The Limit",
    "The Talk Of The Town",
    "The Thrill Is Gone",
    "The Voice Of Reason",
    "The Whole Kit And Caboodle",
    "The Whole Truth And Nothing But The Truth",
    "The Worst Is Over",
    "There's No Time Like The Present",
    "There's No Such Thing As A Free Lunch",
    "Thick As Thieves",
    "Things Are Looking Up",
    "Things Are Tough All Over",
    "Things Change",
    "Third Time's A Charm",
    "Throw In The Towel",
    "Tighten The Purse Strings",
    "Time And A Half",
    "Timing Is Everything",
    "Tip The Scales",
    "To Say The Least",
    "To Your Health",
    "Together In Unison",
    "Too Many Cooks Spoil The Broth",
    "Torn In Half",
    "Transfer Of Deed",
    "Trial And Error",
    "True Blue",
    "Tune It Out",
    "Turned It Down Flat",
    "Turned Tail And Ran",
    "Twenty-Twenty Hindsight",
    "Twice As Nice",
    "Two Of A Kind",
    "Two Wrongs Don't Make A Right",
    "Until Further Notice",
    "Up To The Minute",
    "User-Friendly",
    "Vice Versa",
    "Wait Till Your Father Gets Home",
    "Walk Down The Aisle",
    "Walk The Plank",
    "Wandering Around In A Complete Fog",
    "Watch Out",
    "We're Going Places",
    "We're Poles Apart",
    "We're In The Money",
    "Westward Ho",
    "What A Good Idea",
    "What Do You Make Of That",
    "What Exactly Are You Trying To Say",
    "What's Mine Is Yours",
    "What's The Score",
    "What's Done Is Done",
    "When I Say Jump You Ask How High",
    "When Push Comes To Shove",
    "Where There's A Will There's A Way",
    "Where There's Smoke There's Fire",
    "Wherever You May Roam",
    "Whet Your Appetite",
    "Why Not",
    "Why The Long Face",
    "Win By A Nose",
    "Win Place Or Show",
    "Wipe Out",
    "Wishes Do Come True",
    "With A Little Luck",
    "Within Reason",
    "Without A Trace",
    "Woe Is Me",
    "Won't You Please Join Us",
    "Working Nine To Five",
    "Worth His Weight In Gold",
    "Write It Off",
    "Year In Year Out",
    "You Are Cordially Invited",
    "You Can Take My Place",
    "You Can't Have Your Cake And Eat It Too",
    "You Can't Make A Silk Purse Out Of A Sow's Ear",
    "You Can't Teach An Old Dog New Tricks",
    "Yo'll Have Your Say",
    "Yo're A Saint",
    "Yo're Not My Cup Of Tea",
    "Young At Heart",
    "Your Number's Up",
    "Your Place Or Mine",
    "Yours Truly"
],
"Event": [
    "A Face-Off In Hockey",
    "A Game Of Canasta",
    "A Game Of Simon Says",
    "A Schoolboy Prank",
    "Baby's First Steps",
    "Baseball Double-Header",
    "Birthday",
    "Breaking The Sound Barrier",
    "Bridge Game",
    "Buying On Margin",
    "Car Chase",
    "Charity Auction",
    "Concert",
    "Cramming For An Exam",
    "Cross-Country Skiing",
    "Curtain Call",
    "Demonstration",
    "Dinner",
    "Dire Emergency",
    "Double Feature",
    "Driver Education Class",
    "Earthquake",
    "Easter Egg Hunt",
    "Election",
    "Equipment Shutdown",
    "Festival",
    "Fire Drill",
    "Fistfight",
    "Flashback",
    "Flood",
    "Fly-Fishing",
    "Four-Car Pileup",
    "Four-Minute Mile",
    "Fourth Of July Parade",
    "Fund-Raiser",
    "Fund-Raising Party",
    "Getting A Speeding Ticket",
    "Graduation Day",
    "Grand Slam Home Run",
    "Heart-To-Heart Talk",
    "Hurricane",
    "Indian Summer",
    "Interview",
    "Investing For Your Retirement",
    "Jewish Holiday",
    "Joyride",
    "June Wedding",
    "Landslide",
    "Landslide Victory",
    "Lazy Afternoon",
    "Limbo Contest",
    "Locking Your Keys In Your Car",
    "Macy's Thanksgiving Day Parade",
    "Magic Show",
    "Mardi Gras",
    "Mass Protest",
    "Mowing The Lawn",
    "Nightmare",
    "Opening Night",
    "Overnight Trip",
    "Pajama Party",
    "Papal Audience",
    "Passing Inspection",
    "Passing Your Driver's Test",
    "Pep Rally",
    "Pilgrimage",
    "Pilgrimage",
    "Pony Ride",
    "Potluck Supper",
    "Quilting Bee",
    "Raffle",
    "Rainstorm",
    "Red-Letter Day",
    "Rehearsal",
    "Relay Race",
    "Repeat Performance",
    "Rite Of Passage",
    "Roller Skating",
    "Round Robin Tennis Tournament",
    "Sacking The Quarterback",
    "Scavenger Hunt",
    "Sending Someone A Fax",
    "Shadowboxing",
    "Shipwreck",
    "Shore Leave",
    "Showdown",
    "Snowstorm",
    "Soapbox Derby Race",
    "Sock Hop",
    "Solo Flight",
    "Space Shuttle Launch",
    "Stag Party",
    "State Fair",
    "State Of The Union Address",
    "Sudden Stop",
    "Swap Meet",
    "Sweepstakes Drawing",
    "Symposium",
    "Tag Sale",
    "Tailgate Party",
    "Taking A Nap",
    "Talent Search",
    "The Battle Of Hastings",
    "The Boston Tea Party",
    "The Centennial Olympics",
    "The Johnstown Flood",
    "The Olympic Long Jump",
    "The Olympic Pole Vault",
    "The Watergate Scandal",
    "The World Series",
    "The Battle Of The Bulge",
    "The Boston Tea Party",
    "The Cold War",
    "The War Of The Roses",
    "Touchdown",
    "Tournament",
    "Tournament Of Champions",
    "Tournament Of Roses Parade",
    "Track And Field Competition",
    "Trial By Jury",
    "Tropical Storm",
    "Under House Arrest",
    "Vacation",
    "Volleyball Game",
    "Water-Skiing",
    "Wedding",
    "Wild Goose Chase",
    "Wildcat Strike",
    "Yacht Race",
    "Yalta Conference",
    "Yearly Check-Up"
],
"Occupation": [
    "Ambassador",
    "Anthropologist",
    "Architect",
    "Astronaut",
    "Author",
    "Automobile Mechanic",
    "Bellman",
    "Blacksmith",
    "Bodyguard",
    "Bookkeeper",
    "Bus Driver",
    "Cab Driver",
    "Camp Counselor",
    "Carpenter",
    "Certified Public Accountant",
    "Checkout Clerk",
    "Chemist",
    "Circus Clown",
    "Copywriter",
    "Crossing Guard",
    "Custodian",
    "Customs Officer",
    "Dean Of Students",
    "Detective",
    "Doctor",
    "Doorman",
    "Editor",
    "Electrician",
    "Engineer",
    "English Teacher",
    "Executive Chef",
    "File Clerk",
    "Financial Planner",
    "Fire Fighter",
    "Fire Marshal",
    "Fireman",
    "Flight Attendant",
    "Football Coach",
    "Freelance Writer",
    "Front Desk Clerk",
    "General Contractor",
    "Hairdresser",
    "Handyman",
    "Headhunter",
    "High School Football Coach",
    "High School Guidance Counselor",
    "Insurance Underwriter",
    "Journalist",
    "Landlord",
    "Landscape Architect",
    "Lawyer",
    "Lifeguard",
    "Longshoreman",
    "Magazine Editor",
    "Masseur",
    "Mathematician",
    "Mayor",
    "Method Actor",
    "Music Teacher",
    "Newspaper Columnist",
    "Night Manager",
    "Obstetrician",
    "Office Manager",
    "Parking Attendant",
    "Pharmacist",
    "Pit Boss",
    "Plain Clothes Detective",
    "Playwright",
    "Plumber",
    "Podiatrist",
    "Police Lieutenant",
    "Police Officer",
    "Portrait Painter",
    "Postmaster General",
    "Preacher",
    "Real Estate Salesman",
    "Repairman",
    "Reporter",
    "Research Associate",
    "Sailor",
    "Sales Clerk",
    "School Principal",
    "School Teacher",
    "Scribe",
    "Secretary",
    "Security Guard",
    "Senate Page",
    "Shoemaker",
    "Short-Order Cook",
    "Stockbroker",
    "Tailor",
    "Talk Show Host",
    "Telephone Operator",
    "Telephone Repairman",
    "Test Pilot",
    "Tour Guide",
    "Truck Driver",
    "Underwriter",
    "University Professor",
    "Used Car Salesman",
    "Usher",
    "Violinist",
    "Waiter",
    "Waitress",
    "Writer"
]
}
```
:::
:::

::: {style="width: 100%"}
::: {ea-publisher="runestoneacademy" ea-type="image" style="display: flex; justify-content: center"}
:::
:::

::: {#scprogresscontainer}
You have attempted []{#scprogresstotal} of []{#scprogressposs}
activities on this page

::: {#subchapterprogress aria-label="Page progress"}
:::
:::

-   [[](ChapterAssessment.html)]{#relations-prev}
-   [[](../AdvancedAccumulation/toctree.html)]{#relations-next}
:::

::: {.container}
[]{#numuserspan}[]{.loggedinuser} \| [Back to top](#)

© Copyright 2017 bradleymiller. Created using
[Runestone](http://runestoneinteractive.org/) 7.2.10.
:::
